

package Cooler 
model cooler "Modelo fsico" 
   parameter Integer N "Numero de volmenes de control en dimensin horizontal";
   parameter Integer M "Numero de volmenes de control en dimensin vertical";
    
   // ------------
   // Ventiladores
   // ------------
   // Volmenes de control en los que introduce aire cada ventilador
   // Ventilador 1: i: N_vents[1], ..., N_vents[2]-1 : 1,2,3,4,5,6
   // Ventilador 2: i: N_vents[2], ..., N_vents[3]-1 : 7,8,9,10,11,12
   // Ventilador 3: i: N_vents[3], ..., N_vents[4]-1 : 13,14,15,16,17,18
   // Ventilador 4: i: N_vents[4], ..., N_vents[Nventiladores]-1 : 19,20,21,22,23,24
   // Ventilador Nventiladores=5: i: N_vents[Nventiladores], ..., N : 25,26,27,28,29,30
   parameter Integer Nventiladores; // = 5 "Nmero de ventiladores";
   parameter Integer N_vents[Nventiladores]; // = {1,7,13,19,25};
    
    // --------------------------------------
    // Posicin divisin en free board region
    // --------------------------------------
    // El aire recogido en  i:1,...,(NdivFreeBoard-1) sale por la izquierda
    // El aire recogido en  i: NdivFreeBoard, ..., N  sale por la derecha
    parameter Integer NdivFreeBoard; // = 13;
    
    // Temperaturas aproximadas (cond. inic iteracin)
    parameter Real Tg_IN( unit="K") = 800;
    parameter Real Ts_IN( unit="K") = 1000;
    
   constant Real numericEps = 5 "Constante de tiempo del modelo dinmico";
   constant Boolean modeloDinamico;
    
   // Dimensiones de la unidad de proceso
   Real L(unit="m") "Longitud: dimensin x";
   Real H(unit="m") "Altura: dimensin en y";
    
   // Parmetros relacionados con el tamao del volumen de control
   Real VC_x( unit="m");
   Real VC_y( unit="m");
   Real VC_xy( unit="m2");
    
   // Porosidad
   Real eps( unit="1");
   // Densidades
   Real rho_s( unit="kg/m3");
   Real rho_g( unit="kg/m3");
   // Capacidades calorficas
   Real Cps( unit="J/(kg.K)");
   Real Cpg( unit="J/(kg.K)");
    
   // Conductividad trmica del clinker
   Real ks( unit="J/(m.s.K)");
   Real ks_x( unit="J/(m.s.K)") 
      "Coef transmisin de calor por conduccin en el slido en direccin x";
   Real ks_y( unit="J/(m.s.K)") 
      "Coef transmisin de calor por conduccin en el slido en direccin y";
    
   // Parmetros del flujo de calor por conveccin
   Real DiameterClinker( unit="m") "Diametro del clinker";
   Real a(  unit="1/m");
   Real esfericidadPartClinker( unit="1") 
      "Esfericidad de las particulas de clinker";
   Real CteNumReynolds_g( unit="Kg/(m.s)") 
      "Parte constante del nmero de Reynolds";
    
   // Parmetros del flujo por radiacin
   constant Real sig(   unit="W/(m2.K4)") = 5.670373e-8 
      "Constante de Stefan-Boltzman";
   Real es(  unit="1") "Emisividad del clinker";
   Real Krad(   unit="W/(m.K4)");
    
   // -------------- inicio (free board region) ---------------------
   // Free board region
   Real Tfb[N]( unit="K", start=Tg_IN*ones(N), fixed=modeloDinamico) 
      "temperatura del gas en free board region";
    
   Real FMfb_left[N]( unit="kg/(s.m)") 
      "flujo msico de gas que entra por el lado izquierdo";
   Real FMfb_right[N]( unit="kg/(s.m)") 
      "flujo msico de gas que entra por el lado derecho";
   Real FMfb_bot[N]( unit="kg/(s.m)") 
      "flujo msico de gas que entra por debajo";
    
   Real Ffb_left[N]( unit="J/(m.s)") 
      "Flujo de entalpa que entra por el lado izquierdo";
   Real Ffb_right[N]( unit="J/(m.s)") 
      "Flujo de entalpa que entra por el lado izquierdo";
   Real Ffb_bot[N]( unit="J/(m.s)") 
      "Flujo de entalpa que entra por el lado izquierdo";
   Real Rad[N]( unit="J/(m.s)") "Flujo de energa que entra por radiacin";
   // -------------- fin (free board region) ---------------------
    
   // Temperatura de gas, de slido y de la capa lmite
   Real Tg[N,M]( unit="K", start=Tg_IN*ones(N,M), fixed=modeloDinamico) 
      "temperatura del gas";
   Real Ts[N,M]( unit="K", start=Ts_IN*ones(N,M), fixed=modeloDinamico) 
      "temperatura del slido";
   Real Tf[N,M]( unit="K") "temperatura de la capa lmite gas-slido";
    
   // Flujos de entalpa debido al slido entrante al volumen de control
   Real Fs_left[N,M](    unit="J/(m.s)") 
      "Flujo de entalpa debido al slido que entra por lado izquierdo";
   Real Fs_right[N,M](   unit="J/(m.s)") 
      "Flujo de entalpa debido al slido que entra por lado derecho";
    
   // Flujos de entalpa debido al gas entrante al volumen de control
   Real Fg_bot[N,M](  unit="J/(m.s)") 
      "Flujo de entalpa debido al slido que entra por lado inferior";
   Real Fg_up[N,M](  unit="J/(m.s)") 
      "Flujo de entalpa debido al slido que entra por lado superior";
    
   // Flujos de calor en el slido entrantes por conduccin
   Real Qs_left[N,M](  unit="J/(m.s)") 
      "Flujo de calor que entra por lado izquierdo por conduccin en el slido";
   Real Qs_right[N,M](  unit="J/(m.s)") 
      "Flujo de calor que entra por lado derecho por conduccin en el slido";
   Real Qs_bot[N,M](  unit="J/(m.s)") 
      "Flujo de calor que entra por lado inferior por conduccin en el slido";
   Real Qs_up[N,M](  unit="J/(m.s)") 
      "Flujo de calor que entra por lado superior por conduccin en el slido";
    
  //  Flujo de calor del slido al gas por conveccin
  Real Qsg[N,M](  unit="J/(m.s)") 
      "Flujo de calor transmitido del slido al gas por conveccin";
  Real NumReynolds_g[N,M]( unit="1") "Nmero de Reynolds del gas";
    
  constant Real viscosity_g_coef1 = 0.01827e-3*(0.555*524.07+120)*(9/5/524.07)^(3/2);
  constant Real viscosity_g_coef2 = 0.555*9/5;
  Real viscosity_g[N,M]( unit="kg/(m.s)") "Viscosidad del gas";
  // Real factorChiltonColburn[N,M]( unit="1") "factor de Chilton-Colburn";
  Real hcc[N,M](   unit="J/(m2.s.K)") 
      "Coeficiente transferencia de calor por conveccin";  // = 74;
  Real kg[N,M](  unit="J/(m.s.K)") "Conductividad trmica en el gas";
  Real Nusselt[N,M]( unit="1") "Nusselt number";
  Real Prandtl[N,M]( unit="1") "Prandtl number";
    
  // Flujo de calor del slido al gas por radiacin
  Real R[N,M](   unit="J/(m.s)") 
      "Flujo de calor por radiacin entre el slido y el gas";
    
  // Temperatura a la que entra el gas y el slido (condicin de contorno)
  Real Tg_in(  unit="K") "Temperatura a la que entra en el enfriador el gas";
  Real Ts_in(  unit="K") "Temperatura a la que entra en el enfriador el slido";
    
  // Velocidades de movimiento del gas y del slido
  Real ug_y[N]( unit="m/s") "Velocidad del gas, en sentido de abajo a arriba";
  Real ug_y_vent[Nventiladores]( unit="m/s") 
      "Velocidad del gas, en sentido de abajo a arriba, producida por cada ventilador";
    
  Real us_x( unit="m/s") 
      "Velocidad del slido, en sentido de izquierda a derecha";
    
  // Flujo msico de slido y gas
   Real K_ug( unit="kg/m2") 
      "Constante de proporcionalidad entre el flujo y la velocidad";
   Real FMs(  unit="kg/(s.m)") 
      "Flujo msico de slido a traves de cada volumen de control";
   Real FMg[N](  unit="kg/(s.m)") 
      "Flujo msico de gas a traves de cada volumen de control";
   Real FMs_total( unit="kg/(s.m)") "Flujo msico total de slido";
   Real FMg_total( unit="kg/(s.m)") "Flujo msico total de aire";
   Real FMg_vent[Nventiladores]( unit="kg/(s.m)") 
      "Flujo msico total de cada ventilador";
    
   // Eficiencia
   Real eficiencia( unit="%") "Eficiencia del enfriador";
    
   Real residuoEnergia;
equation 
    
   // Magnitudes relacionadas con el tamao del volumen de control
   VC_x = L/N;
   VC_y = H/M;
   VC_xy = VC_x*VC_y;
    
   // Coef transmisin de calor por conduccin en el slido en direccin x
   ks_x =  VC_y*ks*(1-eps)/VC_x;
   // Coef transmisin de calor por conduccin en el slido en direccin y
   ks_y =  VC_x*ks*(1-eps)/VC_y;
    
   // Flujo msico de slido y de gas
   FMs = VC_y*rho_s*(1-eps)*us_x;
   // FMg = VC_x*rho_g*eps*ug_y;
   FMs_total = rho_s*(1-eps)*us_x*H;
   FMg_total = FMg_vent*ones(Nventiladores);
    
   // Velocidades del gas
   K_ug = VC_x*rho_g*eps;
   for i in 1:(Nventiladores-1) loop
      for j in N_vents[i]:(N_vents[i+1]-1) loop
         FMg[j] = K_ug*ug_y[j];
         FMg[j] = FMg_vent[i]/(N_vents[i+1]-N_vents[i]);
      end for;
   end for;
   for j in N_vents[Nventiladores]:N loop
      FMg[j] = K_ug*ug_y[j];
      FMg[j] = FMg_vent[Nventiladores]/(N+1-N_vents[Nventiladores]);
   end for;
   for i in 1:Nventiladores loop
      ug_y_vent[i] = ug_y[N_vents[i]];
   end for;
    
   // Balance de energa en el slido
   if (modeloDinamico) then
      Fs_left + Fs_right + Qs_left + Qs_right + Qs_bot + Qs_up - Qsg - R = numericEps*der(Ts);
   else
      Fs_left + Fs_right + Qs_left + Qs_right + Qs_bot + Qs_up - Qsg - R = zeros(N,M);
   end if;
    
   // Balance de energa en el gas
   if (modeloDinamico) then
      Fg_bot + Fg_up + Qsg = numericEps*der(Tg);
   else
      Fg_bot + Fg_up + Qsg = zeros(N,M);
   end if;
    
  // Flujos de entalpa del slido
  for i in 1:N loop
     for j in 1:M loop
        Fs_right[i,j] = - FMs*Cps*Ts[i,j];
     end for;
  end for;
  for j in 1:M loop
     Fs_left[1,j] = FMs*Cps*Ts_in;
     for i in 2:N loop
        Fs_left[i,j] = - Fs_right[i-1,j];
     end for;
  end for;
    
  // Flujos de entalpa del gas
  for i in 1:N loop
     for j in 1:M loop
        Fg_up[i,j] = - FMg[i]*Cpg*Tg[i,j];
     end for;
  end for;
  for i in 1:N loop
     Fg_bot[i,1] = FMg[i]*Cpg*Tg_in;
     for j in 2:M loop
        Fg_bot[i,j] = - Fg_up[i,j-1];
     end for;
  end for;
    
  // Flujos de calor por conduccin en el slido
  for j in 1:M loop
     Qs_left[1,j] = 0;
     for i in 2:N loop
       Qs_left[i,j] = ks_x*(Ts[i-1,j]-Ts[i,j]);
     end for;
  end for;
  for j in 1:M loop
     for i in 1:(N-1) loop
       Qs_right[i,j] = ks_x*(Ts[i+1,j]-Ts[i,j]);
     end for;
     Qs_right[N,j] = 0;
  end for;
    
  for i in 1:N loop
     Qs_bot[i,1] = 0;
     for j in 2:M loop
        Qs_bot[i,j] = ks_y*(Ts[i,j-1]-Ts[i,j]);
     end for;
  end for;
  for i in 1:N loop
     for j in 1:(M-1) loop
        Qs_up[i,j] = ks_y*(Ts[i,j+1]-Ts[i,j]);
     end for;
     Qs_up[i,M] = 0;
  end for;
    
   // Flujos de calor del slido al gas por conveccin
   a = 6*(1-eps)/DiameterClinker;
   for i in 1:N loop
     for j in 1:M loop
        Qsg[i,j] = VC_xy*a*hcc[i,j]*( Ts[i,j] - Tg[i,j]);
     end for;
   end for;
   // Numero de Reynolds, viscosidad del gas, temperatura capa lmite gas-slido
   // Conductividad trmica del gas, Coef transferencia calor por conveccin
   CteNumReynolds_g = DiameterClinker*rho_g/(1-eps)/esfericidadPartClinker;
    
   for i in 1:N loop
      for j in 1:M loop
         Tf[i,j] = (Tg[i,j]+Ts[i,j])/2;
         viscosity_g[i,j]   = viscosity_g_coef1/(viscosity_g_coef2*Tf[i,j]+120)*Tf[i,j]^1.5;
         // viscosity_g[i,j]   = 0.01827e-3*(0.555*524.07+120)/(0.555*Tf[i,j]*9/5+120)*(Tf[i,j]*9/5/524.07)^(3/2);
         NumReynolds_g[i,j] = CteNumReynolds_g*ug_y[i]/viscosity_g[i,j];
         //factorChiltonColburn[i,j] = 2.19*NumReynolds_g[i,j]^(-2/3) + 0.78*NumReynolds_g[i,j]^(-0.381);
         // kg[i,j]=1.5207*1e-11*(Tf[i,j])^3-4.8574*1e-8*(Tf[i,j])^2+1.0184*1e-4*Tf[i,j]-3.9333*1e-4;
         kg[i,j]=7e-5*Tf[i,j]+0.0042;
         // hcc[i,j] = factorChiltonColburn[i,j]*rho_g*ug_y[i]*kg[i,j]/viscosity_g[i,j];
        
         hcc[i,j] = Nusselt[i,j]*kg[i,j]/DiameterClinker;
         // Ec. (3.32) del libro de Mujundar y Ramade
         // Nusselt[i,j]=8.74+9.34*(6*(1-eps))^0.2*NumReynolds_g[i,j]^0.2*Prandtl[i,j]^(1/3);
         // Ec. (21) del artculo de Touil et al., que proviene del handbook de Perry
         Nusselt[i,j]=0.0295*NumReynolds_g[i,j]^0.8*Prandtl[i,j]^0.333333;
         Prandtl[i,j]=viscosity_g[i,j]*Cpg/kg[i,j];
      end for;
   end for;
    
   // Flujo de calor por radiacin entre el slido y el gas
   for i in 1:N loop
      R[i,M] = Rad[i];
      for j in 1:(M-1) loop
         R[i,j] = 0;
      end for;
   end for;
    
   // ---------------------------------------------------
   // Free board area
   // ---------------------------------------------------
   // Balance de masa en el estacionario en free board area
   FMfb_left + FMfb_right + FMfb_bot = zeros(N);
   FMfb_left[NdivFreeBoard] = 0;
   for i in 2:N loop
      FMfb_left[i] = - FMfb_right[i-1];
   end for;
   FMfb_bot = FMg;
    
   // Balance de energa en free board region
   if (modeloDinamico) then
      Ffb_left + Ffb_right + Ffb_bot + Rad = numericEps*der(Tfb);
   else
      Ffb_left + Ffb_right + Ffb_bot + Rad = zeros(N);
   end if;
    
   // Flujo de entalpa
   Ffb_left[NdivFreeBoard] = 0;
   for i in 2:N loop
      Ffb_left[i] = - Ffb_right[i-1];
   end for;
   for i in 1:N loop
      Ffb_bot[i] = - Fg_up[i,M];
   end for;
   Krad =  VC_x*sig*es*(1-eps);
   for i in 1:N loop
      Rad[i] = Krad*(Ts[i,M]^4 - Tfb[i]^4);
   end for;
    
   // Relacin entre flujos de entalpa, flujo de masa y temperatura
   for i in 1:(NdivFreeBoard-1) loop
      Ffb_left[i] = FMfb_left[i]*Cpg* Tfb[i];
   end for;
   for i in NdivFreeBoard:N loop
      Ffb_right[i] = FMfb_right[i]*Cpg* Tfb[i];
   end for;
    
   // ---------------------------------------------------
    
   // Eficiencia
    
   eficiencia = -100*Ffb_left[1] / sum( Fs_left[1,j] for j in 1:M);
   residuoEnergia =
      sum( Fs_right[N,j] for j in 1:M) +
      sum( Fs_left[1,j] for j in 1:M) +
      sum( Fg_bot[i,1] for i in 1:N) +
      Ffb_left[1]+
      Ffb_right[N];
end cooler;
  
model coolerInteractive 
    
  protected 
   constant Real Kelvin_to_C = 273.16;
   constant Real Kg_s_to_ton_day = 60*60*24/1000;
    
   constant Integer N =  30 
      "Numero de volmenes de control en dimensin horizontal";
   constant Integer M =  20 
      "Numero de volmenes de control en dimensin vertical";
   // ------------
   // Ventiladores
   // ------------
   // Volmenes de control en los que introduce aire cada ventilador
   // Ventilador 1: i: N_vents[1], ..., N_vents[2]-1 : 1,2,3,4,5,6
   // Ventilador 2: i: N_vents[2], ..., N_vents[3]-1 : 7,8,9,10,11,12
   // Ventilador 3: i: N_vents[3], ..., N_vents[4]-1 : 13,14,15,16,17,18
   // Ventilador 4: i: N_vents[4], ..., N_vents[Nventiladores]-1 : 19,20,21,22,23,24
   // Ventilador Nventiladores=5: i: N_vents[Nventiladores], ..., N : 25,26,27,28,29,30
   constant Integer Nventiladores = 5 "Nmero de ventiladores";
   constant Integer N_vents[Nventiladores] = {1,7,13,19,25};
    
    // --------------------------------------
    // Posicin divisin en free board region
    // --------------------------------------
    // El aire recogido en  i:1,...,(NdivFreeBoard-1) sale por la izquierda
    // El aire recogido en  i: NdivFreeBoard, ..., N  sale por la derecha
    constant Integer NdivFreeBoard = 13;
    
   constant Boolean modeloDinamico = true;
   cooler cool(N=N,M=M,Nventiladores=Nventiladores,N_vents=N_vents,NdivFreeBoard=NdivFreeBoard,modeloDinamico=modeloDinamico);
    
// ---------------------------------------------------
// ------- Variables manipuladas (inicio) ------------
// --- Parmetros modelo fsico
  public 
   Real LIni = 11;
   Real HIni = 0.8;
   Real L(unit="m", start=11, fixed=true) "Longitud del lecho: dimensin x";
   Real H(unit="m", start=0.8, fixed=true) "Altura del lecho: dimensin en y";
   Real eps( unit="1", start=0.825, fixed=true) "Porosidad del clinker";
   Real rho_s( unit="kg/m3", start = 1500, fixed=true) "Densidad del clinker";
   Real rho_g( unit="kg/m3", start = 1.184, fixed=true) "Densidad del aire";
   // Capacidades calorficas
   Real Cps( unit="J/(kg.K)", start = 1000, fixed=true) 
      "Capacidad calorfica del clinker";
   Real Cpg( unit="J/(kg.K)", start = 1009, fixed=true) 
      "Capacidad calorfica del aire";
   Real ks( unit="J/(m.s.K)", start = 0.5, fixed=true) 
      "Conductividad trmica del clinker";
   Real DiameterClinker( unit="m", start = 0.007, fixed=true) 
      "Diametro de la partcula de clinker";
   Real esfericidadPartClinker( unit="1", start = 1, fixed=true) 
      "Esfericidad de las particulas de clinker";
   Real es(  unit="1", start = 0.78, fixed=true) "Emisividad del clinker";
    
// --- Condiciones de contorno para el slido
   Real Ts_in(  unit="C", start=1673-Kelvin_to_C, fixed=true) 
      "Temperatura a la que entra en el enfriador el slido";
   Real FMs_total( unit="ton/day/m", start=30*Kg_s_to_ton_day, fixed=true) 
      "Flujo msico total de slido";
    
// --- Condiciones de contorno para el gas
   Real Tg_in(  unit="C", start=300-Kelvin_to_C, fixed=true) 
      "Temperatura del gas";
   Real FMg_vent[Nventiladores]( unit="kg/s/m", start={11,10,10,10,9}, fixed=true) 
      "Flujo msico total de cada ventilador";
    
// ------- Variables manipuladas (fin) ------------
// ------------------------------------------------
    
// ---------------------------------------------------
// ------- Variables observadas  (inicio) ------------
    
   // Free board region (FBR)
   Real Tfb[N]( unit="C") "Temperatura del gas en free board region";
   Real Tfb_left( unit="C") 
      "Temperatura del aire que sale de FBR por la izquierda";
   Real Tfb_right( unit="C") 
      "Temperatura del aire que sale de FBR por la derecha";
   Real FMfb_left_1( unit="kg/s/m") 
      "Flujo de masa que sale de FBR por la izquierda";
   Real FMfb_right_N( unit="kg/s/m") 
      "Flujo de masa que sale de FBR por la derecha";
    
   // Gas en el lecho
   Real Tg[N,M]( unit="C") "Temperatura del gas en el lecho";
   Real ug_y_vent[Nventiladores]( unit="m/s") 
      "Velocidad del gas, en sentido de abajo a arriba, producida por cada ventilador";
    
   // Slido en el lecho
   Real Ts[N,M]( unit="C") "Temperatura del slido";
   Real us_x( unit="m/s") 
      "Velocidad del slido, en sentido de izquierda a derecha";
   // Temperatura media gas-slido
   Real Tf[N,M]( unit="C") "Temperatura media gas-slido";
    
   // Temperatura promedio de salida del clinker
   Real Ts_out_promedio(  unit="C") 
      "Temperatura promedio de salida del clinker";
    
   // Eficiencia
   Real eficiencia( unit="%") "Eficiencia del enfriador";
    
// ------- Variables observadas  (fin) ------------
// ------------------------------------------------
    
equation 
   // Variables manipuladas
   L = cool.L;
   der(L) = 0;
   H = cool.H;
   der(H) = 0;
   eps = cool.eps;
   der(eps) = 0;
   rho_s = cool.rho_s;
   der(rho_s) = 0;
   rho_g = cool.rho_g;
   der(rho_g) = 0;
   Cps = cool.Cps;
   der(Cps) = 0;
   Cpg = cool.Cpg;
   der(Cpg) = 0;
   ks = cool.ks;
   der(ks) = 0;
   DiameterClinker = cool.DiameterClinker;
   der(DiameterClinker) = 0;
   esfericidadPartClinker = cool.esfericidadPartClinker;
   der(esfericidadPartClinker) = 0;
   es = cool.es;
   der(es) = 0;
   Ts_in = cool.Ts_in - Kelvin_to_C;
   der(Ts_in) = 0;
   FMs_total = cool.FMs_total * Kg_s_to_ton_day;
   der(FMs_total) = 0;
   Tg_in = cool.Tg_in - Kelvin_to_C;
   der(Tg_in) = 0;
   FMg_vent = cool.FMg_vent;
   der(FMg_vent) = zeros(Nventiladores);
    
   // Variables observadas
   Tfb = cool.Tfb - Kelvin_to_C*ones(N);
   Tfb_left = cool.Tfb[1] - Kelvin_to_C;
   Tfb_right = cool.Tfb[N] - Kelvin_to_C;
   FMfb_left_1 = -cool.FMfb_left[1];
   FMfb_right_N = -cool.FMfb_right[N];
   Tg = cool.Tg - Kelvin_to_C*ones(N,M);
   Ts = cool.Ts - Kelvin_to_C*ones(N,M);
   us_x = cool.us_x;
   Tf = cool.Tf - Kelvin_to_C*ones(N,M);
   ug_y_vent = cool.ug_y_vent;
   eficiencia = cool.eficiencia;
    
   Ts_out_promedio = sum( Ts[N,i] for i in 1:M) /M;
  annotation (experiment(
      Interval=0.5,
      Tolerance=0.01,
      Algorithm="Dassl"), experimentSetupOutput(derivatives=false));
end coolerInteractive;
  
  model View 
    extends Interactive.VLabModels.PartialView;
    parameter Integer N=15;
    //30;
    parameter Integer M=10;
    //20;
    
    Interactive.ViewElements.Containers.MainWindow mW(
      LayoutPolicy="VBox",
      title="Cooler",
      Width=600,
      Height=400) annotation (extent=[-44,265; -16,295]);
    Interactive.ViewElements.Containers.Panel pN(LayoutPolicy="VBox") 
      annotation (extent=[-5,263; 15,283]);
    annotation (Coordsys(
        extent=[-100,-300; 200,300],
        grid=[1,1],
        scale=0.01), Diagram(coordinateSystem(preserveAspectRatio=true, extent=
              {{-100,-100},{200,300}}), graphics));
    Interactive.ViewElements.Containers.GroupBox cG(
      LayoutPolicy="Grid",
      title="Clinker properties",
      columnSpan=5,
      row=0,
      column=0) 
         annotation (extent=[38,280; 58,301]);
    Interactive.ViewElements.Containers.GroupBox aG(
      LayoutPolicy="Grid",
      title="Air properties",
      columnSpan=4,
      row=0,
      column=0) 
      annotation (extent=[38,247; 58,267]);
    Interactive.ViewElements.BasicElements.Label tempClinkL(
      row=0,
      column=0,
      text="Input temperature (920-1500 \\u00B0C)") 
      annotation (extent=[63,282; 83,302]);
    Interactive.ViewElements.InteractiveControls.NumberField tempClinker(
      numberOfDecimals=0,
      row=0,
      column=1,
      step=100,
      minValue=920,
      maxValue=1500,
      initialValue=1200) annotation (extent=[64,266; 84,286]);
    Interactive.ViewElements.BasicElements.CheckBox cB1(
      row=0,
      column=4,
      label="Parameters",
      varName="clinkParam") annotation (extent=[129,277; 149,297]);
    Interactive.ViewElements.BasicElements.Label massClinkL1(
      row=0,
      column=2,
      text="Clinker mass flow ( ton/day/m)") 
      annotation (extent=[97,281; 117,301]);
    Interactive.ViewElements.InteractiveControls.NumberField mflowClinker(
      numberOfDecimals=0,
      row=0,
      column=3,
      minValue=864,
      maxValue=8640,
      step=100,
      initialValue=1500) annotation (extent=[98,266; 118,286]);
    Interactive.ViewElements.InteractiveControls.NumberField tempAir(
      numberOfDecimals=0,
      row=0,
      column=1,
      step=1.0,
      minValue=15,
      maxValue=40,
      initialValue=25) annotation (extent=[61,225; 81,245]);
    Interactive.ViewElements.BasicElements.Label airL(
      row=0,
      column=0,
      text="Input temperature (15-40 \\u00B0C)") 
      annotation (extent=[61,241; 81,261]);
    Interactive.ViewElements.BasicElements.CheckBox cB2(
      row=0,
      label="Parameters",
      varName="airParam",
      column=2) annotation (extent=[93,243; 113,263]);
    Interactive.ViewElements.BasicElements.CheckBox cB3(
      row=0,
      column=3,
      label="Fans - air mass flow",
      varName="fans") annotation (extent=[92,222; 112,242]);
    Interactive.ViewElements.Containers.Panel pN1(LayoutPolicy="Grid") 
      annotation (extent=[-8,70; 12,90]);
    Interactive.ViewElements.Containers.GroupBox plots(
      LayoutPolicy="Grid",
      column=0,
      title="Plots",
      row=0,
      rowSpan=1,
      columnSpan=4) annotation (extent=[21,61; 41,81]);
    Interactive.ViewElements.BasicElements.CheckBox cB4(
      varName="clinkerTemp",
      row=0,
      column=0,
      label="Clinker temp.") annotation (extent=[53,60; 73,80]);
    Interactive.ViewElements.BasicElements.CheckBox cB5(
      row=0,
      varName="airVTemp",
      column=1,
      label="Air vertical temp.") annotation (extent=[81,60; 101,80]);
    Interactive.ViewElements.BasicElements.CheckBox cB6(
      row=0,
      varName="airHTemp",
      column=2,
      label="Air horizontal temp.") annotation (extent=[108,60; 128,80]);
    Interactive.ViewElements.BasicElements.CheckBox cB7(
      row=0,
      varName="avgTemp",
      column=3,
      label="Cooler average temp.") annotation (extent=[133,61; 153,81]);
    Interactive.ViewElements.BasicElements.CheckBox cB8(
      row=0,
      varName="documentation",
      label="Documentation",
      column=4) annotation (extent=[19,41; 39,61]);
    Interactive.ViewElements.BasicElements.PauseButton pauseButton(
      row=0,
      initialValue="true",
      column=5) annotation (extent=[37,263; 57,283]);
    Interactive.ViewElements.BasicElements.CheckBox cB9(
      row=0,
      varName="coolerParam",
      label="Cooler param.",
      column=4) annotation (extent=[36,224; 56,244]);
    Interactive.ViewElements.Containers.Canvas cV 
      annotation (extent=[-3,198; 17,218]);
    Interactive.ViewElements.Drawables.PlanarGrid clinker(
      displayVectors=0,
      linearVectorLUT=0,
      dims={N,M,0},
      minRangeVectorLUT=0,
      maxRangeVectorLUT=1350,
      minRangeCellLUT=10,
      maxRangeCellLUT=1500,
      intPos=1, 
      minSatRangeCellLUT=1, 
      maxSatRangeCellLUT=1) 
                annotation (extent=[27,201; 47,221]);
    Interactive.ViewElements.Drawables.PlanarGrid air(
      displayVectors=0,
      linearVectorLUT=0,
      linearScaleCellLUT=1,
      dims={N,M,0},
      minRangeVectorLUT=0,
      maxRangeVectorLUT=1350,
      minRangeCellLUT=10,
      maxRangeCellLUT=1500,
      intPos=1) annotation (extent=[26,175; 46,195]);
    Interactive.ViewElements.Drawables.ScalarBar sB(
      maxNColors=70,
      title="Temperature C",
      minRange=0,
      maxRange=1350,
      nLabels=11) annotation (extent=[26,150; 46,170]);
    Interactive.ViewElements.Drawables.Polygon poly1(edgeVisibility=1, nSides=4) 
      annotation (extent=[26,127; 46,147]);
    Interactive.ViewElements.Drawables.Polygon poly2(edgeVisibility=1, nSides=4) 
      annotation (extent=[58,200; 78,220]);
    Interactive.ViewElements.Drawables.Polygon poly3(edgeVisibility=1, nSides=4) 
      annotation (extent=[58,179; 78,199]);
    Interactive.ViewElements.Drawables.Polygon poly4(edgeVisibility=1, nSides=4) 
      annotation (extent=[58,161; 78,181]);
    Interactive.ViewElements.Drawables.Polygon poly5(edgeVisibility=1, nSides=4) 
      annotation (extent=[58,141; 78,161]);
    Interactive.ViewElements.Drawables.Text text(
      text="Clinker",
      colorp={0,0,0},
      colorlp={0,0,0},
      scale=0.4) annotation (extent=[59,134; 73,144]);
    Interactive.ViewElements.Drawables.Text text1(
      text="Air",
      colorp={0,0,0},
      colorlp={0,0,0},
      scale=0.4) annotation (extent=[59,118; 73,128]);
    Interactive.ViewElements.Drawables.Disk disk1(
      colorp={0,0,0},
      edgeVisibility=1,
      colorlp={0,0,0}) annotation (extent=[83,202; 103,222]);
    Interactive.ViewElements.Drawables.Disk disk2(
      colorp={0,0,0},
      edgeVisibility=1,
      colorlp={0,0,0}) annotation (extent=[83,181; 103,201]);
    Interactive.ViewElements.Drawables.Disk disk3(
      colorp={0,0,0},
      edgeVisibility=1,
      colorlp={0,0,0}) annotation (extent=[83,160; 103,180]);
    Interactive.ViewElements.Drawables.Disk disk4(
      colorp={0,0,0},
      edgeVisibility=1,
      colorlp={0,0,0}) annotation (extent=[83,140; 103,160]);
    Interactive.ViewElements.Drawables.Disk disk5(
      colorp={0,0,0},
      edgeVisibility=1,
      colorlp={0,0,0}) annotation (extent=[83,119; 103,139]);
    Interactive.ViewElements.Drawables.Polygon cuad1(
      edgeVisibility=1,
      nSides=4,
      colorp={0,0,0},
      opacityp=1,
      colorlp={0,0,0},
      polygon=1) annotation (extent=[107,200; 127,220]);
    Interactive.ViewElements.Drawables.Polygon cuad2(
      edgeVisibility=1,
      nSides=4,
      colorp={0,0,0},
      opacityp=1,
      colorlp={0,0,0},
      polygon=1) annotation (extent=[107,180; 127,200]);
    Interactive.ViewElements.Drawables.Polygon cuad3(
      edgeVisibility=1,
      nSides=4,
      colorp={0,0,0},
      opacityp=1,
      colorlp={0,0,0},
      polygon=1) annotation (extent=[107,160; 127,180]);
    Interactive.ViewElements.Drawables.Polygon cuad4(
      edgeVisibility=1,
      nSides=4,
      colorp={0,0,0},
      opacityp=1,
      colorlp={0,0,0},
      polygon=1) annotation (extent=[107,140; 127,160]);
    Interactive.ViewElements.Drawables.Polygon cuad5(
      edgeVisibility=1,
      nSides=4,
      colorp={0,0,0},
      opacityp=1,
      colorlp={0,0,0},
      polygon=1) annotation (extent=[107,119; 127,139]);
    Interactive.ViewElements.Drawables.PlanarGrid air1(
      displayVectors=0,
      linearVectorLUT=0,
      linearScaleCellLUT=1,
      dims={N,M,0},
      minRangeVectorLUT=0,
      maxRangeVectorLUT=1350,
      minRangeCellLUT=10,
      maxRangeCellLUT=1500,
      intPos=1) annotation (extent=[131,175; 151,195]);
    Interactive.ViewElements.Drawables.PlanarGrid clinker1(
      displayVectors=0,
      linearVectorLUT=0,
      dims={N,M,0},
      minRangeVectorLUT=0,
      maxRangeVectorLUT=1350,
      minRangeCellLUT=10,
      maxRangeCellLUT=1500,
      intPos=1) annotation (extent=[131,199; 151,219]);
    Interactive.ViewElements.Drawables.PlanarGrid clinker2(
      displayVectors=0,
      linearVectorLUT=0,
      dims={N,M,0},
      minRangeVectorLUT=0,
      maxRangeVectorLUT=1350,
      minRangeCellLUT=10,
      maxRangeCellLUT=1500,
      intPos=1) annotation (extent=[131,156; 151,176]);
    Interactive.ViewElements.Drawables.PlanarGrid air2(
      displayVectors=0,
      linearVectorLUT=0,
      linearScaleCellLUT=1,
      dims={N,M,0},
      minRangeVectorLUT=0,
      maxRangeVectorLUT=1350,
      minRangeCellLUT=10,
      maxRangeCellLUT=1500,
      intPos=1) annotation (extent=[130,134; 150,154]);
    Interactive.ViewElements.Drawables.PlanarGrid clinker3(
      displayVectors=0,
      linearVectorLUT=0,
      dims={N,M,0},
      minRangeVectorLUT=0,
      maxRangeVectorLUT=1350,
      minRangeCellLUT=10,
      maxRangeCellLUT=1500,
      intPos=1) annotation (extent=[130,109; 150,129]);
    Interactive.ViewElements.Drawables.PlanarGrid air3(
      displayVectors=0,
      linearVectorLUT=0,
      linearScaleCellLUT=1,
      dims={N,M,0},
      minRangeVectorLUT=0,
      maxRangeVectorLUT=1350,
      minRangeCellLUT=10,
      maxRangeCellLUT=1500,
      intPos=1) annotation (extent=[131,90; 151,110]);
    Interactive.ViewElements.Drawables.PlanarGrid airFB(
      displayVectors=0,
      linearVectorLUT=0,
      linearScaleCellLUT=1,
      dims={30,1,0},
      minRangeVectorLUT=0,
      maxRangeVectorLUT=1350,
      minRangeCellLUT=10,
      maxRangeCellLUT=1500,
      intPos=1) annotation (extent=[164,200; 184,220]);
    Interactive.ViewElements.Drawables.Polygon polySecondary(edgeVisibility=1,
        nSides=6) annotation (extent=[26,108; 49,127]);
    Interactive.ViewElements.Drawables.Polygon polyTerciary(edgeVisibility=1,
        nSides=6) annotation (extent=[26,90; 46,110]);
    Interactive.ViewElements.Drawables.TextReal text2(
      colorp={0,0,0},
      colorlp={0,0,0},
      scale=0.4,
      initText="T sec. air = ",
      finalText=" (\\u00B0C)",
      intValue=1) annotation (extent=[166,177; 186,197]);
    Interactive.ViewElements.Drawables.TextReal text3(
      colorp={0,0,0},
      colorlp={0,0,0},
      scale=0.4,
      initText="T terc. air = ",
      finalText=" (\\u00B0C)",
      intValue=1) annotation (extent=[166,152; 186,172]);
    Interactive.src.ViewElements.Drawables.Arrow arrowL(colorp={0,0,0}, colorlp=
         {0,0,0}) annotation (extent=[166,129; 186,149]);
    Interactive.src.ViewElements.Drawables.Arrow arrowR(colorp={0,0,0}, colorlp=
         {0,0,0}) annotation (extent=[166,113; 186,133]);
    Interactive.ViewElements.Containers.Panel pN2(LayoutPolicy="Grid") 
      annotation (extent=[19,283; 39,303]);
    Interactive.ViewElements.Containers.Panel pN3(LayoutPolicy="Grid") 
      annotation (extent=[17,250; 37,270]);
    Interactive.ViewElements.Drawables.TextReal text4(
      colorp={0,0,0},
      colorlp={0,0,0},
      scale=0.4,
      initText="T out = ",
      finalText=" (\\u00B0C)",
      intValue=1) annotation (extent=[166,95; 186,115]);
    Interactive.src.ViewElements.Drawables.Arrow arrowR1(
                                  colorp={0,0,0}, colorlp={0,0,0}) 
      annotation (extent=[165,75; 185,95]);
    Interactive.ViewElements.Containers.Dialog dialog(
      varName="clinkerTemp",
      Width=600,
      title="Clinker Temp.",
      xPosition=0) 
       annotation (extent=[-39,33; -19,53]);
    Interactive.ViewElements.Containers.PlottingPanel plottingPanel(
      titleY="T (C)",
      placeLegend="true",
      checkableLegend="true",
      title="Clinker  temp.",
      titleX="Number of CV (1: left -30:right)",
      autoscalex="false",
      autoscaley="false") annotation (extent=[-11,24; 9,44]);
    Interactive.ViewElements.Drawables.TrailNPoints trail1ClinkerT(nPoints=30,
        trailLabel="Clinker[1]-bottom") 
                    annotation (extent=[21,21; 41,41]);
    Interactive.ViewElements.Drawables.TrailNPoints trail10ClinkerT(
      nPoints=30,
      lineColor="red",
      trailLabel="Clinker[10]-middle") annotation (extent=[52,21; 72,41]);
    Interactive.ViewElements.Drawables.TrailNPoints trail20ClinkerT(
      nPoints=30,
      lineColor="blue",
      trailLabel="Clinker[20]-top") 
  annotation (extent=[95,22; 115,42]);
    Interactive.ViewElements.Containers.Dialog dialog1(
      Width=600,
      varName="airVTemp",
      title="Air Vertical Temp.",
      xPosition=0) 
            annotation (extent=[-40,5; -20,25]);
    Interactive.ViewElements.Containers.PlottingPanel plottingPanel1(
      titleY="T (C)",
      placeLegend="true",
      checkableLegend="true",
      title="Air Vertical temp.",
      autoscalex="false",
      autoscaley="false",
      titleX="Number of CV (1: bottom -20: top)") 
      annotation (extent=[-12,-2; 8,18]);
    Interactive.ViewElements.Drawables.TrailNPoints trail1AirT(nPoints=20,
        trailLabel="Air[1]-entry") 
                annotation (extent=[20,-4; 40,16]);
    Interactive.ViewElements.Drawables.TrailNPoints trail10AirT(
      lineColor="red",
      nPoints=20,
      trailLabel="Air[15]-middle") 
      annotation (extent=[51,-3; 71,17]);
    Interactive.ViewElements.Drawables.TrailNPoints trail20AirT(
      lineColor="blue",
      nPoints=20,
      trailLabel="Air[30] - exit") 
            annotation (extent=[93,-3; 113,17]);
    Interactive.ViewElements.Containers.Dialog dialog2(
      Width=600,
      title="Air Horizonal Temp.",
      varName="airHTemp",
      xPosition=0) 
    annotation (extent=[-40,-24; -20,-4]);
    Interactive.ViewElements.Containers.PlottingPanel plottingPanel2(
      titleY="T (C)",
      placeLegend="true",
      checkableLegend="true",
      titleX="Number of CV (1: left -30:right)",
      title="Air Horizontal temp.",
      autoscalex="false",
      autoscaley="false") 
              annotation (extent=[-12,-31; 8,-11]);
    Interactive.ViewElements.Drawables.TrailNPoints trail1AirHT(nPoints=30,
        trailLabel="Air[1]-bottom") 
                annotation (extent=[20,-33; 40,-13]);
    Interactive.ViewElements.Drawables.TrailNPoints trail10AirHT(
      nPoints=30,
      lineColor="red",
      trailLabel="Air[10]-middle") 
      annotation (extent=[51,-32; 71,-12]);
    Interactive.ViewElements.Drawables.TrailNPoints trail20AirHT(
      nPoints=30,
      lineColor="blue",
      trailLabel="Air[20]-top") 
            annotation (extent=[94,-32; 114,-12]);
    Interactive.ViewElements.Containers.Dialog dialog3(
      Width=600,
      title="Cooler averagel Temp.",
      varName="avgTemp",
      xPosition=0) 
    annotation (extent=[-39,-49; -19,-29]);
    Interactive.ViewElements.Containers.PlottingPanel plottingPanel3(
      titleY="T (C)",
      titleX="Number of CV (1: left -30:right)",
      title="Cooler average temp.",
      autoscalex="false",
      autoscaley="false",
      placeLegend="true",
      checkableLegend="true") 
         annotation (extent=[-11,-56; 9,-36]);
    Interactive.ViewElements.Drawables.TrailNPoints trail1Cooler(nPoints=30,
        trailLabel="Bottom") annotation (extent=[21,-58; 41,-38]);
    Interactive.ViewElements.Containers.Dialog dialog4(
      Width=600,
      title="Documentation",
      varName="documentation",
      xPosition=0) 
         annotation (extent=[-39,-72; -19,-52]);
    Interactive.ViewElements.BasicElements.Browser browser(path=
          "./www/index.html") 
        annotation (extent=[-5,-80; 15,-60]);
    Interactive.ViewElements.Containers.Dialog dialog5(
      title="Cooler param.",
      Width=400,
      Height=200,
      varName="coolerParam",
      LayoutPolicy="Grid",
      xPosition=0) 
     annotation (extent=[-39,-100; -19,-80]);
    Interactive.ViewElements.BasicElements.Label tempClinkL1(
      row=0,
      column=0,
      text="Length (0-15 m)") annotation (extent=[-1,-101; 19,-81]);
    Interactive.ViewElements.InteractiveControls.NumberField length(
      row=0,
      column=1,
      minValue=0.001,
      maxValue=15,
      step=0.1,
      initialValue=1,
      numberOfDecimals=1) annotation (extent=[25,-101; 45,-81]);
    Interactive.ViewElements.BasicElements.Label tempClinkL2(
      column=0,
      text="Height (0-2 m)",
      row=1) annotation (extent=[55,-101; 75,-81]);
    Interactive.ViewElements.InteractiveControls.NumberField height(
      column=1,
      minValue=0.001,
      step=0.1,
      initialValue=1,
      numberOfDecimals=1,
      maxValue=2,
      row=1) annotation (extent=[81,-101; 101,-81]);
    Interactive.ViewElements.Containers.Dialog dialog6(
      Width=400,
      Height=200,
      LayoutPolicy="Grid",
      title="Clinker param.",
      varName="clinkParam",
      xPosition=0) 
      annotation (extent=[-39,-128; -19,-108]);
    Interactive.ViewElements.BasicElements.Label tempClinkL3(
      row=0,
      column=0,
      text="Porosity (0.2-0.8)") annotation (extent=[0,-130; 20,-110]);
    Interactive.ViewElements.InteractiveControls.NumberField porosity(
      row=0,
      column=1,
      numberOfDecimals=1,
      minValue=0.2,
      maxValue=0.8,
      step=0.05,
      initialValue=0.5) annotation (extent=[26,-131; 46,-111]);
    Interactive.ViewElements.BasicElements.Label tempClinkL4(
      text="Density (1200-1600 Kg/m^3)",
      row=1,
      column=0) annotation (extent=[56,-131; 76,-111]);
    Interactive.ViewElements.InteractiveControls.NumberField density(
      step=0.1,
      minValue=1200,
      maxValue=1600,
      initialValue=1400,
      numberOfDecimals=0,
      row=1,
      column=1) annotation (extent=[82,-131; 102,-111]);
    Interactive.ViewElements.Containers.Dialog dialog7(
      Width=400,
      Height=200,
      LayoutPolicy="Grid",
      title="Air param.",
      varName="airParam",
      xPosition=0) 
    annotation (extent=[-39,-156; -19,-136]);
    Interactive.ViewElements.BasicElements.Label tempClinkL5(
      column=0,
      text="Density (1-2 Kg/m^3)",
      row=0) annotation (extent=[-4,-163; 16,-143]);
    Interactive.ViewElements.InteractiveControls.NumberField airDensity(
      step=0.1,
      column=1,
      minValue=1,
      maxValue=2,
      initialValue=1.5,
      numberOfDecimals=1,
      row=0) annotation (extent=[31,-164; 51,-144]);
    Interactive.ViewElements.Containers.Dialog dialog8(
      Width=400,
      Height=200,
      LayoutPolicy="Grid",
      title="Fans air mass flow",
      varName="fans",
      xPosition=0) annotation (extent=[-39,-192; -19,-172]);
    Interactive.ViewElements.BasicElements.Label tempClinkL6(
      row=0,
      column=0,
      text="Fan 1 leftest ( 1-15 kg/s/m)") annotation (extent=[0,-194; 20,-174]);
    Interactive.ViewElements.InteractiveControls.NumberField fan1(
      row=0,
      column=1,
      numberOfDecimals=1,
      step=0.05,
      minValue=1,
      maxValue=15,
      initialValue=2) annotation (extent=[26,-195; 46,-175]);
    Interactive.ViewElements.BasicElements.Label tempClinkL7(
      row=1,
      column=0,
      text="Fan 2 ( 1-15 kg/s/m)") annotation (extent=[56,-195; 76,-175]);
    Interactive.ViewElements.InteractiveControls.NumberField fan2(
      numberOfDecimals=1,
      step=0.05,
      minValue=1,
      maxValue=15,
      initialValue=2,
      row=1,
      column=1) annotation (extent=[82,-195; 102,-175]);
    Interactive.ViewElements.BasicElements.Label tempClinkL8(
      column=0,
      row=2,
      text="Fan 3 ( 1-15 kg/s/m)") annotation (extent=[3,-224; 23,-204]);
    Interactive.ViewElements.InteractiveControls.NumberField fan3(
      column=1,
      numberOfDecimals=1,
      step=0.05,
      minValue=1,
      maxValue=15,
      initialValue=2,
      row=2) annotation (extent=[29,-225; 49,-205]);
    Interactive.ViewElements.BasicElements.Label tempClinkL9(
      column=0,
      row=3,
      text="Fan 4 ( 1-15 kg/s/m)") annotation (extent=[59,-225; 79,-205]);
    Interactive.ViewElements.InteractiveControls.NumberField fan4(
      numberOfDecimals=1,
      step=0.05,
      minValue=1,
      maxValue=15,
      initialValue=2,
      column=1,
      row=3) annotation (extent=[85,-225; 105,-205]);
    Interactive.ViewElements.BasicElements.Label tempClinkL10(
      column=0,
      row=4,
      text="Fan 5 rightest ( 1-15 kg/s/m)") 
      annotation (extent=[0,-250; 20,-230]);
    Interactive.ViewElements.InteractiveControls.NumberField fan5(
      numberOfDecimals=1,
      step=0.05,
      minValue=1,
      maxValue=15,
      initialValue=2,
      column=1,
      row=4) annotation (extent=[26,-250; 46,-230]);
    Interactive.ViewElements.Drawables.TrailNPoints trail20Cooler(
      nPoints=30,
      lineColor="blue",
      trailLabel="Top") annotation (extent=[82,-60; 102,-40]);
    Interactive.ViewElements.Drawables.TrailNPoints trail10Cooler(
      nPoints=30,
      lineColor="red",
      trailLabel="Middle") annotation (extent=[50,-56; 70,-36]);
  equation 
    connect(root.cLLeft, mW.pLLeft) annotation (points=[-70.2,61; -70,61; -70,
          56; -57,56; -57,284.2; -42.6,284.2], style(color=0, rgbcolor={0,0,0}));
    connect(cG.cLRight, tempClinkL.pLLeft) annotation (points=[57,290.5; 60,
          290.5; 60,297; 64,297],
     style(color=0, rgbcolor={0,0,0}));
    connect(tempClinkL.cLLeft, tempClinker.pLLeft) annotation (points=[64,291;
          62,291; 62,281; 65,281],
          style(color=0, rgbcolor={0,0,0}));
    connect(tempClinker.cLLeft, massClinkL1.pLLeft) annotation (points=[65,275;
          65,276; 62,276; 62,268; 88,268; 88,296; 98,296], style(color=0,
          rgbcolor={0,0,0}));
    connect(massClinkL1.cLLeft, mflowClinker.pLLeft) annotation (points=[98,290;
          96,290; 96,281; 99,281], style(color=0, rgbcolor={0,0,0}));
    connect(mflowClinker.cLLeft, cB1.pLLeft) annotation (points=[99,275; 97,275;
          97,269; 122,269; 122,292; 130,292], style(color=0, rgbcolor={0,0,0}));
    connect(aG.cLRight, airL.pLLeft) annotation (points=[57,257; 57,256; 62,256],
        style(color=0, rgbcolor={0,0,0}));
    connect(airL.cLLeft, tempAir.pLLeft) annotation (points=[62,250; 58,250; 58,
          240; 62,240], style(color=0, rgbcolor={0,0,0}));
    connect(tempAir.cLLeft, cB2.pLLeft) annotation (points=[62,234; 58,234; 58,
          229; 85,229; 85,258; 94,258], style(color=0, rgbcolor={0,0,0}));
    connect(cB2.cLLeft, cB3.pLLeft) annotation (points=[94,252; 90,252; 90,237;
          93,237], style(color=0, rgbcolor={0,0,0}));
    connect(plots.cLRight, cB4.pLLeft) annotation (points=[40,71; 46.5,71; 46.5,
          75; 54,75], style(color=0, rgbcolor={0,0,0}));
    connect(cB4.cLLeft, cB5.pLLeft) annotation (points=[54,69; 53,69; 53,60; 75,
          60; 75,75; 82,75], style(color=0, rgbcolor={0,0,0}));
    connect(cB5.cLLeft, cB6.pLLeft) annotation (points=[82,69; 80,69; 80,68; 77,
          68; 77,60; 104,60; 104,75; 109,75], style(color=0, rgbcolor={0,0,0}));
    connect(cB6.cLLeft, cB7.pLLeft) annotation (points=[109,69; 107,69; 107,60;
          131,60; 131,76; 134,76], style(color=0, rgbcolor={0,0,0}));
    connect(plots.cLLeft, cB8.pLLeft) annotation (points=[22,68; 17,68; 17,56;
          20,56], style(color=0, rgbcolor={0,0,0}));
    connect(cV.cRight, clinker.pLeft) annotation (points=[16,208; 20,208; 20,
          216; 28,216], style(color=0, rgbcolor={0,0,0}));
    connect(clinker.cLeft, air.pLeft) annotation (points=[28,208; 23,208; 23,
          190; 27,190], style(color=0, rgbcolor={0,0,0}));
    connect(air.cLeft, sB.pLeft) annotation (points=[27,182; 24,182; 24,165; 27,
          165], style(color=0, rgbcolor={0,0,0}));
    connect(sB.cLeft, poly1.pLeft) annotation (points=[27,157; 24,157; 24,142;
          27,142], style(color=0, rgbcolor={0,0,0}));
    connect(poly2.cLeft, poly3.pLeft) annotation (points=[59,207; 55,207; 55,
          194; 59,194], style(color=0, rgbcolor={0,0,0}));
    connect(poly3.cLeft, poly4.pLeft) annotation (points=[59,186; 55,186; 55,
          176; 59,176], style(color=0, rgbcolor={0,0,0}));
    connect(poly4.cLeft, poly5.pLeft) annotation (points=[59,168; 55,168; 55,
          156; 59,156], style(color=0, rgbcolor={0,0,0}));
    connect(poly5.cLeft, text.pLeft) annotation (points=[59,148; 55,148; 55,
          141.5; 59.7,141.5], style(color=0, rgbcolor={0,0,0}));
    connect(text.cLeft, text1.pLeft) annotation (points=[59.7,137.5; 55,137.5;
          55,125.5; 59.7,125.5],
      style(color=0, rgbcolor={0,0,0}));
    connect(text1.cLeft, disk1.pLeft) annotation (points=[59.7,121.5; 56,121.5;
          56,116; 76,116; 76,217; 84,217],
                style(color=0, rgbcolor={0,0,0}));
    connect(disk1.cLeft, disk2.pLeft) annotation (points=[84,209; 80,209; 80,
          196; 84,196], style(color=0, rgbcolor={0,0,0}));
    connect(disk2.cLeft, disk3.pLeft) annotation (points=[84,188; 80,188; 80,
          175; 84,175], style(color=0, rgbcolor={0,0,0}));
    connect(disk3.cLeft, disk4.pLeft) annotation (points=[84,167; 80,167; 80,
          155; 84,155], style(color=0, rgbcolor={0,0,0}));
    connect(disk4.cLeft, disk5.pLeft) annotation (points=[84,147; 80,147; 80,
          134; 84,134], style(color=0, rgbcolor={0,0,0}));
    connect(cuad1.cLeft, cuad2.pLeft) annotation (points=[108,207; 104,207; 104,
          195; 108,195], style(color=0, rgbcolor={0,0,0}));
    connect(cuad2.cLeft, cuad3.pLeft) annotation (points=[108,187; 104,187; 104,
          175; 108,175], style(color=0, rgbcolor={0,0,0}));
    connect(cuad3.cLeft, cuad4.pLeft) annotation (points=[108,167; 106,167; 106,
          168; 104,168; 104,155; 108,155],
                   style(color=0, rgbcolor={0,0,0}));
    connect(cuad4.cLeft, cuad5.pLeft) annotation (points=[108,147; 105,147; 105,
          134; 108,134], style(color=0, rgbcolor={0,0,0}));
    connect(disk5.cLeft, cuad1.pLeft) annotation (points=[84,126; 82,126; 82,
          125; 79,125; 79,116; 101,116; 101,215; 108,215],
                          style(color=0, rgbcolor={0,0,0}));
    connect(cuad5.cLeft, clinker1.pLeft) annotation (points=[108,126; 106,126;
          106,116; 124,116; 124,214; 132,214],
                   style(color=0, rgbcolor={0,0,0}));
    connect(text2.cLeft, text3.pLeft) annotation (points=[167,184; 162,184; 162,
          167; 167,167], style(color=0, rgbcolor={0,0,0}));
    connect(text3.cLeft, arrowL.pLeft) annotation (points=[167,159; 162,159;
          162,144; 167,144], style(color=0, rgbcolor={0,0,0}));
    connect(arrowL.cLeft, arrowR.pLeft) annotation (points=[167,136; 161,136;
          161,128; 167,128], style(color=0, rgbcolor={0,0,0}));
    connect(cV.pLLeft, pN.cLLeft) annotation (points=[-2,213; -10,213; -10,270;
          -4,270], style(color=0, rgbcolor={0,0,0}));
    connect(pN.cLRight, pN2.pLLeft) annotation (points=[14,273; 16,273; 16,
          295.8; 20,295.8], style(color=0, rgbcolor={0,0,0}));
    connect(pN2.cLRight, cG.pLLeft) annotation (points=[38,293; 36,293; 36,
          293.44; 39,293.44], style(color=0, rgbcolor={0,0,0}));
    connect(pN2.cLLeft, pN3.pLLeft) annotation (points=[20,290; 20,262.8; 18,
          262.8], style(color=0, rgbcolor={0,0,0}));
    connect(aG.pLLeft, pN3.cLRight) annotation (points=[39,259.8; 38,259.8; 38,
          260; 36,260], style(color=0, rgbcolor={0,0,0}));
    connect(cG.cLLeft, pauseButton.pLLeft) annotation (points=[39,287.35; 39,
          283.175; 38,283.175; 38,278], style(color=0, rgbcolor={0,0,0}));
    connect(aG.cLLeft, cB9.pLLeft) annotation (points=[39,254; 38,254; 38,239;
          37,239], style(color=0, rgbcolor={0,0,0}));
    connect(poly1.cLeft, polySecondary.pLeft) annotation (points=[27,134; 26,
          134; 26,135; 23,135; 23,122.25; 27.15,122.25],
                          style(color=0, rgbcolor={0,0,0}));
    connect(polySecondary.cLeft, polyTerciary.pLeft) annotation (points=[27.15,
          114.65; 23,114.65; 23,105; 27,105],
           style(color=0, rgbcolor={0,0,0}));
    connect(polyTerciary.cLeft, poly2.pLeft) annotation (points=[27,97; 23,97;
          23,93; 50,93; 50,215; 59,215], style(color=0, rgbcolor={0,0,0}));
    connect(arrowR.cLeft, text4.pLeft) annotation (points=[167,120; 160,120;
          160,110; 167,110],
   style(color=0, rgbcolor={0,0,0}));
    connect(plots.pLLeft, pN1.cLRight) annotation (points=[22,73.8; 17,73.8; 17,
          80; 11,80], style(color=0, rgbcolor={0,0,0}));
    connect(airFB.cLeft, text2.pLeft) annotation (points=[165,207; 161,207; 161,
          192; 167,192], style(color=0, rgbcolor={0,0,0}));
    connect(text4.cLeft, arrowR1.pLeft) annotation (points=[167,102; 160,102;
          160,90; 166,90], style(color=0, rgbcolor={0,0,0}));
    connect(pN1.pLLeft, cV.cLLeft) annotation (points=[-7,82.8; -10,82.8; -10,
          205; -2,205], style(color=0, rgbcolor={0,0,0}));
    connect(pN.pLLeft, mW.cLRight) annotation (points=[-4,275.8; -7,275.8; -7,
          276; -10,276; -10,280; -17.4,280], style(color=0, rgbcolor={0,0,0}));
    connect(clinker1.cLeft, air1.pLeft) annotation (points=[132,206; 128,206;
          128,190; 132,190], style(color=0, rgbcolor={0,0,0}));
    connect(air1.cLeft, clinker2.pLeft) annotation (points=[132,182; 128,182;
          128,171; 132,171], style(color=0, rgbcolor={0,0,0}));
    connect(clinker2.cLeft, air2.pLeft) annotation (points=[132,163; 128,163;
          128,149; 131,149], style(color=0, rgbcolor={0,0,0}));
    connect(air2.cLeft, clinker3.pLeft) annotation (points=[131,141; 128,141;
          128,124; 131,124], style(color=0, rgbcolor={0,0,0}));
    connect(clinker3.cLeft, air3.pLeft) annotation (points=[131,116; 128,116;
          128,105; 132,105], style(color=0, rgbcolor={0,0,0}));
    connect(air3.cLeft, airFB.pLeft) annotation (points=[132,97; 127,97; 127,85;
          156,85; 156,215; 165,215], style(color=0, rgbcolor={0,0,0}));
    connect(mW.cLLeft, dialog.pLLeft) annotation (points=[-42.6,275.5; -50,
          275.5; -50,45.8; -38,45.8], style(color=0, rgbcolor={0,0,0}));
    connect(plottingPanel.pLLeft, dialog.cLRight) annotation (points=[-10,39; -14,
          39; -14,43; -20,43],
         style(color=0, rgbcolor={0,0,0}));
    connect(trail1ClinkerT.pLeft, plottingPanel.cRight) annotation (points=[22,
          36; 20,36; 20,34; 8,34], style(color=0, rgbcolor={0,0,0}));
    connect(trail1ClinkerT.cLeft, trail10ClinkerT.pLeft) annotation (points=[22,
          28; 22,25; 49,25; 49,36; 53,36], style(color=0, rgbcolor={0,0,0}));
    connect(trail10ClinkerT.cLeft, trail20ClinkerT.pLeft) annotation (points=[
          53,28; 55,28; 55,25; 78,25; 78,37; 96,37], style(color=0, rgbcolor={0,
            0,0}));
    connect(dialog.cLLeft, dialog1.pLLeft) annotation (points=[-38,40; -50,40;
          -50,17.8; -39,17.8], style(color=0, rgbcolor={0,0,0}));
    connect(trail1AirT.pLeft, plottingPanel1.cRight) annotation (points=[21,11;
          19,11; 19,8; 7,8], style(color=0, rgbcolor={0,0,0}));
    connect(trail1AirT.cLeft, trail10AirT.pLeft) annotation (points=[21,3; 21,0;
          48,0; 48,12; 52,12], style(color=0, rgbcolor={0,0,0}));
    connect(trail10AirT.cLeft, trail20AirT.pLeft) annotation (points=[52,4; 54,
          4; 54,0; 77,0; 77,12; 94,12],
               style(color=0, rgbcolor={0,0,0}));
    connect(plottingPanel1.pLLeft, dialog1.cLRight) annotation (points=[-11,13;
          -16,13; -16,15; -21,15], style(color=0, rgbcolor={0,0,0}));
    connect(trail1AirHT.pLeft, plottingPanel2.cRight) annotation (points=[21,-18;
          19,-18; 19,-21; 7,-21], style(color=0, rgbcolor={0,0,0}));
    connect(trail1AirHT.cLeft, trail10AirHT.pLeft) annotation (points=[21,-26;
          21,-29; 48,-29; 48,-17; 52,-17], style(color=0, rgbcolor={0,0,0}));
    connect(trail10AirHT.cLeft, trail20AirHT.pLeft) annotation (points=[52,-25;
          54,-25; 54,-29; 77,-29; 77,-17; 95,-17], style(color=0, rgbcolor={0,0,
            0}));
    connect(plottingPanel2.pLLeft, dialog2.cLRight) annotation (points=[-11,-16;
          -16,-16; -16,-14; -21,-14], style(color=0, rgbcolor={0,0,0}));
    connect(dialog1.cLLeft, dialog2.pLLeft) annotation (points=[-39,12; -46,12;
          -46,11; -50,11; -50,-11.2; -39,-11.2], style(color=0, rgbcolor={0,0,0}));
    connect(trail1Cooler.pLeft, plottingPanel3.cRight) 
                                annotation (points=[22,-43;20,-43;20,-46;8,-46],
        style(color=0, rgbcolor={0,0,0}));
    connect(plottingPanel3.pLLeft, dialog3.cLRight) annotation (points=[-10,-41;
          -15,-41; -15,-39; -20,-39], style(color=0, rgbcolor={0,0,0}));
    connect(dialog2.cLLeft, dialog3.pLLeft) annotation (points=[-39,-17; -45,-17;
          -45,-16; -51,-16; -51,-36.2; -38,-36.2], style(color=0, rgbcolor={0,0,
            0}));
    connect(browser.pLLeft, dialog4.cLRight) annotation (points=[-4,-65; -12,-65;
          -12,-62; -20,-62], style(color=0, rgbcolor={0,0,0}));
    connect(dialog3.cLLeft, dialog4.pLLeft) annotation (points=[-38,-42; -52,-42;
          -52,-59.2; -38,-59.2], style(color=0, rgbcolor={0,0,0}));
    connect(dialog5.cLRight, tempClinkL1.pLLeft) annotation (points=[-20,-90; -11.5,
          -90; -11.5,-86; 0,-86], style(color=0, rgbcolor={0,0,0}));
    connect(tempClinkL1.cLLeft, length.pLLeft) annotation (points=[0,-92; -6,-92;
          -6,-99; 20,-99; 20,-86; 26,-86], style(color=0, rgbcolor={0,0,0}));
    connect(length.cLLeft, tempClinkL2.pLLeft) annotation (points=[26,-92; 22,-92;
          22,-99; 49,-99; 49,-86; 56,-86], style(color=0, rgbcolor={0,0,0}));
    connect(tempClinkL2.cLLeft, height.pLLeft) annotation (points=[56,-92; 51,-92;
          51,-99; 77,-99; 77,-86; 82,-86], style(color=0, rgbcolor={0,0,0}));
    connect(dialog4.cLLeft, dialog5.pLLeft) annotation (points=[-38,-65; -52,-65;
          -52,-87.2; -38,-87.2], style(color=0, rgbcolor={0,0,0}));
    connect(dialog5.cLLeft, dialog6.pLLeft) annotation (points=[-38,-93; -54,-93;
          -54,-115.2; -38,-115.2], style(color=0, rgbcolor={0,0,0}));
    connect(tempClinkL3.cLLeft, porosity.pLLeft) annotation (points=[1,-121; -5,
          -121; -5,-129; 21,-129; 21,-116; 27,-116], style(color=0, rgbcolor={0,
            0,0}));
    connect(porosity.cLLeft, tempClinkL4.pLLeft) annotation (points=[27,-122;
          23,-122; 23,-129; 50,-129; 50,-116; 57,-116], style(color=0, rgbcolor=
           {0,0,0}));
    connect(tempClinkL4.cLLeft, density.pLLeft) annotation (points=[57,-122; 52,
          -122; 52,-129; 78,-129; 78,-116; 83,-116], style(color=0, rgbcolor={0,
            0,0}));
    connect(dialog6.cLRight, tempClinkL3.pLLeft) annotation (points=[-20,-118;
          -9.5,-118; -9.5,-115; 1,-115], style(color=0, rgbcolor={0,0,0}));
    connect(tempClinkL5.pLLeft, dialog7.cLRight) annotation (points=[-3,-148; -11,
          -148; -11,-146; -20,-146], style(color=0, rgbcolor={0,0,0}));
    connect(dialog6.cLLeft, dialog7.pLLeft) annotation (points=[-38,-121; -46,-121;
          -46,-120; -54,-120; -54,-143.2; -38,-143.2], style(color=0, rgbcolor=
            {0,0,0}));
    connect(tempClinkL5.cLLeft, airDensity.pLLeft) annotation (points=[-3,-154;
          -11,-154; -11,-159; 24,-159; 24,-149; 32,-149], style(color=0,
          rgbcolor={0,0,0}));
    connect(tempClinkL6.cLLeft, fan1.pLLeft) annotation (points=[1,-185; -5,-185;
          -5,-193; 21,-193; 21,-180; 27,-180], style(color=0, rgbcolor={0,0,0}));
    connect(fan1.cLLeft, tempClinkL7.pLLeft) annotation (points=[27,-186; 23,-186;
          23,-193; 50,-193; 50,-180; 57,-180], style(color=0, rgbcolor={0,0,0}));
    connect(tempClinkL7.cLLeft, fan2.pLLeft) annotation (points=[57,-186; 52,-186;
          52,-193; 78,-193; 78,-180; 83,-180], style(color=0, rgbcolor={0,0,0}));
    connect(dialog8.cLRight, tempClinkL6.pLLeft) annotation (points=[-20,-182;
          -9.5,-182; -9.5,-179; 1,-179], style(color=0, rgbcolor={0,0,0}));
    connect(tempClinkL8.cLLeft, fan3.pLLeft) annotation (points=[4,-215; -2,-215;
          -2,-223; 24,-223; 24,-210; 30,-210], style(color=0, rgbcolor={0,0,0}));
    connect(fan3.cLLeft, tempClinkL9.pLLeft) annotation (points=[30,-216; 26,-216;
          26,-223; 53,-223; 53,-210; 60,-210], style(color=0, rgbcolor={0,0,0}));
    connect(tempClinkL9.cLLeft, fan4.pLLeft) annotation (points=[60,-216; 55,-216;
          55,-223; 81,-223; 81,-210; 86,-210], style(color=0, rgbcolor={0,0,0}));
    connect(tempClinkL10.cLLeft, fan5.pLLeft) annotation (points=[1,-241; -4,-241;
          -4,-248; 22,-248; 22,-235; 27,-235], style(color=0, rgbcolor={0,0,0}));
    connect(fan2.cLLeft, tempClinkL8.pLLeft) annotation (points=[83,-186; 83,-199;
          -9,-199; -9,-209; 4,-209], style(color=0, rgbcolor={0,0,0}));
    connect(fan4.cLLeft, tempClinkL10.pLLeft) annotation (points=[86,-216; 85,-216;
          85,-230; -9,-230; -9,-235; 1,-235], style(color=0, rgbcolor={0,0,0}));
    connect(dialog8.pLLeft, dialog7.cLLeft) annotation (points=[-38,-179.2; -46,
          -179.2; -46,-178; -54,-178; -54,-149; -38,-149], style(color=0,
          rgbcolor={0,0,0}));
    connect(trail1Cooler.cLeft, trail10Cooler.pLeft) annotation (points=[22,-51;
          37,-51; 37,-41; 51,-41], style(color=0, rgbcolor={0,0,0}));
    connect(trail10Cooler.cLeft, trail20Cooler.pLeft) annotation (points=[51,-49;
          67,-49; 67,-45; 83,-45], style(color=0, rgbcolor={0,0,0}));
  end View;
  annotation (uses(Interactive(version="2"), Modelica(version="2.2.1")));
  model virtualLab 
    
  import Modelica.Utilities.*;
    
    Interactive.VLabModels.VirtualLab interactive(
      fileName="Program1.cpp",
      redeclare model ViewI = View,
      redeclare model ModelI = coolerInteractive,
      Tcom=1,
      compilation=true) annotation (extent=[-22,50; -2,70]);
    parameter Real sf = 1.5 "Vertical scale factor";
  equation 
    /* DRAWABLES--------------------------
  -------------------------------------*/
    
    interactive.View.clinker.Position = {0, 0, 0};
    interactive.View.clinker.Origin = {0, 0, 0};
    interactive.View.clinker.Degrees = {0, 0, 0};
    interactive.View.clinker.LengthX = interactive.Model.LIni/2;
    interactive.View.clinker.LengthY = interactive.Model.HIni*sf/2;
    interactive.View.clinker.LengthZ =  0.01;
    
    for j in 1: interactive.View.M loop
      for i in 1: interactive.View.N loop  //30
        interactive.View.clinker.scalars[i+(j-1)*interactive.View.N] = interactive.Model.Ts[i,j];  //Ts[N,M]
      end for;
    end for;
    interactive.View.clinker.posGrid = {-interactive.Model.LIni/2,-interactive.Model.HIni*sf*9/8,0.0};
    
    interactive.View.clinker1.Position = {0, 0, 0};
    interactive.View.clinker1.Origin = {0, 0, 0};
    interactive.View.clinker1.Degrees = {0, 0, 0};
    interactive.View.clinker1.LengthX = interactive.Model.LIni/2;
    interactive.View.clinker1.LengthY = interactive.Model.HIni*sf/2;
    interactive.View.clinker1.LengthZ =  0.01;
    
    for j in 1: interactive.View.M loop
      for i in 1: interactive.View.N loop  //30
        interactive.View.clinker1.scalars[i+(j-1)*interactive.View.N] = interactive.Model.Ts[i,j+interactive.View.M];
      end for;
    end for;
    interactive.View.clinker1.posGrid = {-interactive.Model.LIni/2,-interactive.Model.HIni*sf*5/8,0.0};
    
    interactive.View.clinker2.Position = {0, 0, 0};
    interactive.View.clinker2.Origin = {0, 0, 0};
    interactive.View.clinker2.Degrees = {0, 0, 0};
    interactive.View.clinker2.LengthX = interactive.Model.LIni/2;
    interactive.View.clinker2.LengthY = interactive.Model.HIni*sf/2;
    interactive.View.clinker2.LengthZ =  0.01;
    
    for j in 1: interactive.View.M loop
      for i in 1: interactive.View.N loop  //30
        interactive.View.clinker2.scalars[i+(j-1)*interactive.View.N] = interactive.Model.Ts[i+interactive.View.N,j];
      end for;
    end for;
    interactive.View.clinker2.posGrid = {0,-interactive.Model.HIni*sf*9/8,0.0};
    
    interactive.View.clinker3.Position = {0, 0, 0};
    interactive.View.clinker3.Origin = {0, 0, 0};
    interactive.View.clinker3.Degrees = {0, 0, 0};
    interactive.View.clinker3.LengthX = interactive.Model.LIni/2;
    interactive.View.clinker3.LengthY = interactive.Model.HIni*sf/2;
    interactive.View.clinker3.LengthZ =  0.01;
    
    for j in 1: interactive.View.M loop
      for i in 1: interactive.View.N loop  //30
        interactive.View.clinker3.scalars[i+(j-1)*interactive.View.N] = interactive.Model.Ts[i+interactive.View.N,j+interactive.View.M];
      end for;
    end for;
    interactive.View.clinker3.posGrid = {0,-interactive.Model.HIni*sf*5/8,0.0};
    
    /*for i in 1: interactive.View.M loop
    for j in 1: interactive.View.N loop  //30
      interactive.View.clinker3.scalars[j+(i-1)*interactive.View.N] = interactive.Model.Ts[j+interactive.View.N,i+interactive.View.M];
    end for;
  end for;*/
    
    interactive.View.polySecondary.Position = {0, 0, 0};
    interactive.View.polySecondary.Origin = {0, 0, 0};
    interactive.View.polySecondary.Degrees = {0,0,0};
    interactive.View.polySecondary.posVertexes = {-interactive.Model.L/2, 9/8*interactive.Model.H*sf, 0,
  -interactive.Model.L/2-interactive.Model.L*0.025, 9/8*interactive.Model.H*sf+interactive.Model.H*sf*0.1, 0,
  -interactive.Model.L/2-interactive.Model.L*0.025*2, 9/8*interactive.Model.H*sf+interactive.Model.H*sf*0.1, 0,
  -interactive.Model.L/2-interactive.Model.L*0.025*2, 9/8*interactive.Model.H*sf+interactive.Model.H*sf*0.1*4, 0,
  interactive.View.poly3.posVertexes[1]-interactive.Model.L*0.025, 9/8*interactive.Model.H*sf+interactive.Model.H*sf*0.1*4, 0,
  interactive.View.poly3.posVertexes[1], 9/8*interactive.Model.H*sf, 0};
    
    interactive.View.polyTerciary.Position = {0, 0, 0};
    interactive.View.polyTerciary.Origin = {0, 0, 0};
    interactive.View.polyTerciary.Degrees = {0,0,0};
    interactive.View.polyTerciary.posVertexes = {interactive.Model.L/2, 9/8*interactive.Model.H*sf, 0,
  interactive.Model.L/2+interactive.Model.L*0.025, 9/8*interactive.Model.H*sf+interactive.Model.H*sf*0.1, 0,
  interactive.Model.L/2+interactive.Model.L*0.025*2, 9/8*interactive.Model.H*sf+interactive.Model.H*sf*0.1, 0,
  interactive.Model.L/2+interactive.Model.L*0.025*2, 9/8*interactive.Model.H*sf+interactive.Model.H*sf*0.1*4, 0,
  interactive.View.poly3.posVertexes[1]+interactive.Model.L*0.025, 9/8*interactive.Model.H*sf+interactive.Model.H*sf*0.1*4, 0,
  interactive.View.poly3.posVertexes[1], 9/8*interactive.Model.H*sf, 0};
    
    interactive.View.poly1.Position = {0, 0, 0};
    interactive.View.poly1.Origin = {0, 0, 0};
    interactive.View.poly1.Degrees = {0,0,0};
    interactive.View.poly1.posVertexes = {-interactive.Model.L/2, -9/8*interactive.Model.H*sf, 0, -interactive.Model.L*9/20, -11/8*interactive.Model.H*sf, 0, -interactive.Model.L*7/20, -11/8*interactive.Model.H*sf,0, -interactive.Model.L*3/10,  -9/8*interactive.Model.H*sf, 0};
    
    interactive.View.poly2.Position = {0, 0, 0};
    interactive.View.poly2.Origin = {0, 0, 0};
    interactive.View.poly2.Degrees = {0,0,0};
    interactive.View.poly2.posVertexes = {interactive.View.poly1.posVertexes[1]+interactive.Model.L/5, interactive.View.poly1.posVertexes[2], 0, interactive.View.poly1.posVertexes[4]+interactive.Model.L/5,
    interactive.View.poly1.posVertexes[5], 0, interactive.View.poly1.posVertexes[7]+interactive.Model.L/5, interactive.View.poly1.posVertexes[8],0, interactive.View.poly1.posVertexes[10]+interactive.Model.L/5, interactive.View.poly1.posVertexes[11],    0};
    
    interactive.View.poly3.Position = {0, 0, 0};
    interactive.View.poly3.Origin = {0, 0, 0};
    interactive.View.poly3.Degrees = {0,0,0};
    interactive.View.poly3.posVertexes = {interactive.View.poly2.posVertexes[1]+interactive.Model.L/5, interactive.View.poly2.posVertexes[2], 0, interactive.View.poly2.posVertexes[4]+interactive.Model.L/5,
    interactive.View.poly2.posVertexes[5], 0, interactive.View.poly2.posVertexes[7]+interactive.Model.L/5, interactive.View.poly2.posVertexes[8],0, interactive.View.poly2.posVertexes[10]+interactive.Model.L/5, interactive.View.poly2.posVertexes[11],    0};
    
    interactive.View.poly4.Position = {0, 0, 0};
    interactive.View.poly4.Origin = {0, 0, 0};
    interactive.View.poly4.Degrees = {0,0,0};
    interactive.View.poly4.posVertexes = {interactive.View.poly3.posVertexes[1]+interactive.Model.L/5, interactive.View.poly3.posVertexes[2], 0, interactive.View.poly3.posVertexes[4]+interactive.Model.L/5,
    interactive.View.poly3.posVertexes[5], 0, interactive.View.poly3.posVertexes[7]+interactive.Model.L/5, interactive.View.poly3.posVertexes[8],0, interactive.View.poly3.posVertexes[10]+interactive.Model.L/5, interactive.View.poly3.posVertexes[11],    0};
    
    interactive.View.poly5.Position = {0, 0, 0};
    interactive.View.poly5.Origin = {0, 0, 0};
    interactive.View.poly5.Degrees = {0,0,0};
    interactive.View.poly5.posVertexes = {interactive.View.poly4.posVertexes[1]+interactive.Model.L/5, interactive.View.poly4.posVertexes[2], 0, interactive.View.poly4.posVertexes[4]+interactive.Model.L/5,
    interactive.View.poly4.posVertexes[5], 0, interactive.View.poly4.posVertexes[7]+interactive.Model.L/5, interactive.View.poly4.posVertexes[8],0, interactive.View.poly4.posVertexes[10]+interactive.Model.L/5, interactive.View.poly4.posVertexes[11],    0};
    
    interactive.View.disk1.OuterRadius = interactive.Model.H/8*sf;
    interactive.View.disk1.InnerRadius = interactive.Model.H/8*sf*0.4;
    interactive.View.disk1.Position = {-interactive.Model.L*4/10, -13/8*interactive.Model.H*sf, 0};
    interactive.View.disk1.Origin = {0, 0, 0};
    interactive.View.disk1.Degrees = {0,0,0};
    
    interactive.View.disk2.OuterRadius = interactive.View.disk1.OuterRadius;
    interactive.View.disk2.InnerRadius = interactive.View.disk1.InnerRadius;
    interactive.View.disk2.Position = {interactive.View.disk1.Position[1]+interactive.Model.L/5, interactive.View.disk1.Position[2], 0};
    interactive.View.disk2.Origin = {0, 0, 0};
    interactive.View.disk2.Degrees = {0,0,0};
    
    interactive.View.disk3.OuterRadius = interactive.View.disk1.OuterRadius;
    interactive.View.disk3.InnerRadius = interactive.View.disk1.InnerRadius;
    interactive.View.disk3.Position = {interactive.View.disk2.Position[1]+interactive.Model.L/5, interactive.View.disk2.Position[2], 0};
    interactive.View.disk3.Origin = {0, 0, 0};
    interactive.View.disk3.Degrees = {0,0,0};
    
    interactive.View.disk4.OuterRadius = interactive.View.disk1.OuterRadius;
    interactive.View.disk4.InnerRadius = interactive.View.disk1.InnerRadius;
    interactive.View.disk4.Position = {interactive.View.disk3.Position[1]+interactive.Model.L/5, interactive.View.disk3.Position[2], 0};
    interactive.View.disk4.Origin = {0, 0, 0};
    interactive.View.disk4.Degrees = {0,0,0};
    
    interactive.View.disk5.OuterRadius = interactive.View.disk1.OuterRadius;
    interactive.View.disk5.InnerRadius = interactive.View.disk1.InnerRadius;
    interactive.View.disk5.Position = {interactive.View.disk4.Position[1]+interactive.Model.L/5, interactive.View.disk4.Position[2], 0};
    interactive.View.disk5.Origin = {0, 0, 0};
    interactive.View.disk5.Degrees = {0,0,0};
    
    interactive.View.cuad1.Position = {0, 0, 0};
    interactive.View.cuad1.Origin = {0, 0, 0};
    interactive.View.cuad1.Degrees = {0,0,0};
    interactive.View.cuad1.posVertexes = {interactive.View.disk1.Position[1]+interactive.View.disk1.InnerRadius, interactive.View.disk1.Position[2]+interactive.View.disk1.InnerRadius, 0,
  interactive.View.disk1.Position[1]+interactive.View.disk1.OuterRadius, interactive.View.disk1.Position[2]+interactive.View.disk1.InnerRadius, 0,
  interactive.View.disk1.Position[1]+interactive.View.disk1.OuterRadius, interactive.View.disk1.Position[2]+interactive.View.disk1.InnerRadius*5, 0,
  interactive.View.disk1.Position[1]+interactive.View.disk1.InnerRadius, interactive.View.disk1.Position[2]+interactive.View.disk1.InnerRadius*5, 0};
    
    interactive.View.cuad2.Position = {0, 0, 0};
    interactive.View.cuad2.Origin = {0, 0, 0};
    interactive.View.cuad2.Degrees = {0,0,0};
    interactive.View.cuad2.posVertexes = {interactive.View.cuad1.posVertexes[1]+interactive.Model.L/5, interactive.View.cuad1.posVertexes[2], 0,
  interactive.View.cuad1.posVertexes[4]+interactive.Model.L/5, interactive.View.cuad1.posVertexes[5], 0,
  interactive.View.cuad1.posVertexes[7]+interactive.Model.L/5, interactive.View.cuad1.posVertexes[8], 0,
  interactive.View.cuad1.posVertexes[10]+interactive.Model.L/5, interactive.View.cuad1.posVertexes[11], 0};
    
    interactive.View.cuad3.Position = {0, 0, 0};
    interactive.View.cuad3.Origin = {0, 0, 0};
    interactive.View.cuad3.Degrees = {0,0,0};
    interactive.View.cuad3.posVertexes = {interactive.View.cuad2.posVertexes[1]+interactive.Model.L/5, interactive.View.cuad1.posVertexes[2], 0,
  interactive.View.cuad2.posVertexes[4]+interactive.Model.L/5, interactive.View.cuad1.posVertexes[5], 0,
  interactive.View.cuad2.posVertexes[7]+interactive.Model.L/5, interactive.View.cuad1.posVertexes[8], 0,
  interactive.View.cuad2.posVertexes[10]+interactive.Model.L/5, interactive.View.cuad1.posVertexes[11], 0};
    
    interactive.View.cuad4.Position = {0, 0, 0};
    interactive.View.cuad4.Origin = {0, 0, 0};
    interactive.View.cuad4.Degrees = {0,0,0};
    interactive.View.cuad4.posVertexes = {interactive.View.cuad3.posVertexes[1]+interactive.Model.L/5, interactive.View.cuad1.posVertexes[2], 0,
  interactive.View.cuad3.posVertexes[4]+interactive.Model.L/5, interactive.View.cuad1.posVertexes[5], 0,
  interactive.View.cuad3.posVertexes[7]+interactive.Model.L/5, interactive.View.cuad1.posVertexes[8], 0,
  interactive.View.cuad3.posVertexes[10]+interactive.Model.L/5, interactive.View.cuad1.posVertexes[11], 0};
    
    interactive.View.cuad5.Position = {0, 0, 0};
    interactive.View.cuad5.Origin = {0, 0, 0};
    interactive.View.cuad5.Degrees = {0,0,0};
    interactive.View.cuad5.posVertexes = {interactive.View.cuad4.posVertexes[1]+interactive.Model.L/5, interactive.View.cuad1.posVertexes[2], 0,
  interactive.View.cuad4.posVertexes[4]+interactive.Model.L/5, interactive.View.cuad1.posVertexes[5], 0,
  interactive.View.cuad4.posVertexes[7]+interactive.Model.L/5, interactive.View.cuad1.posVertexes[8], 0,
  interactive.View.cuad4.posVertexes[10]+interactive.Model.L/5, interactive.View.cuad1.posVertexes[11], 0};
    
  //Text clinker
    interactive.View.text.Position = {-interactive.Model.L*1/2*1.4, -interactive.Model.H*sf*5/8, 0};
    interactive.View.text.Origin = {0, 0, 0};
    interactive.View.text.Degrees = {0,0,0};
    
  //Text air
    interactive.View.text1.Position = {-interactive.Model.L*1/2*1.4, interactive.Model.H*sf*5/8, 0};
    interactive.View.text1.Origin = {0, 0, 0};
    interactive.View.text1.Degrees = {0,0,0};
    
  //Text secondary air
    interactive.View.text2.Position = {-interactive.Model.L*1/2*1.4, 9/8*interactive.Model.H*sf+interactive.Model.H*sf*0.1*6, 0};
    interactive.View.text2.Origin = {0, 0, 0};
    interactive.View.text2.Degrees = {0,0,0};
    interactive.View.text2.var = interactive.Model.Tfb_left;
    
  //Text terciary air
    interactive.View.text3.Position = {interactive.View.poly4.posVertexes[1], 9/8*interactive.Model.H*sf+interactive.Model.H*sf*0.1*6, 0};
    interactive.View.text3.Origin = {0, 0, 0};
    interactive.View.text3.Degrees = {0,0,0};
    interactive.View.text3.var = interactive.Model.Tfb_right;
    
  //Text temp. avg. clinker
    interactive.View.text4.Position = {interactive.Model.L*1/2*1.1, -interactive.Model.H*sf*1/3, 0};
    interactive.View.text4.Origin = {0, 0, 0};
    interactive.View.text4.Degrees = {0,0,0};
    interactive.View.text4.var = interactive.Model.Ts_out_promedio;
    
    interactive.View.air.Position = {0, 0, 0};
    interactive.View.air.Origin = {0, 0, 0};
    interactive.View.air.Degrees = {0, 0, 0};
    interactive.View.air.LengthX = interactive.Model.LIni/2;
    interactive.View.air.LengthY = interactive.Model.HIni/2*sf;  //Altura teniendo en cuenta la freeboard region
    interactive.View.air.LengthZ =  0.01;
    for j in 1:interactive.View.M loop
      for i in 1:interactive.View.N loop  //20
        interactive.View.air.scalars[i+(j-1)*interactive.View.N] = interactive.Model.Tg[i,j];
      end for;
    end for;
    /*for i in interactive.View.M+1:interactive.View.M+5 loop
    for j in 1:interactive.View.N loop  //20
      interactive.View.air.scalars[j+(i-1)*interactive.View.N] = interactive.Model.Tfb[j];
    end for;
  end for;*/
    interactive.View.air.posGrid = {-interactive.Model.LIni/2,interactive.Model.HIni*sf/8,0.0};
    
    interactive.View.air1.Position = {0, 0, 0};
    interactive.View.air1.Origin = {0, 0, 0};
    interactive.View.air1.Degrees = {0, 0, 0};
    interactive.View.air1.LengthX = interactive.Model.LIni/2;
    interactive.View.air1.LengthY = interactive.Model.HIni/2*sf;  //Altura teniendo en cuenta la freeboard region
    interactive.View.air1.LengthZ =  0.01;
    for j in 1:interactive.View.M loop
      for i in 1:interactive.View.N loop  //20
        interactive.View.air1.scalars[i+(j-1)*interactive.View.N] = interactive.Model.Tg[i,j+interactive.View.M];
      end for;
    end for;
    interactive.View.air1.posGrid = {-interactive.Model.LIni/2,interactive.Model.HIni*sf*5/8,0.0};
    
    interactive.View.air2.Position = {0, 0, 0};
    interactive.View.air2.Origin = {0, 0, 0};
    interactive.View.air2.Degrees = {0, 0, 0};
    interactive.View.air2.LengthX = interactive.Model.LIni/2;
    interactive.View.air2.LengthY = interactive.Model.HIni/2*sf;  //Altura teniendo en cuenta la freeboard region
    interactive.View.air2.LengthZ =  0.01;
    for j in 1:interactive.View.M loop
      for i in 1:interactive.View.N loop  //20
        interactive.View.air2.scalars[i+(j-1)*interactive.View.N] = interactive.Model.Tg[i+interactive.View.N,j];
      end for;
    end for;
    interactive.View.air2.posGrid = {0,interactive.Model.HIni*sf/8,0.0};
    
    interactive.View.air3.Position = {0, 0, 0};
    interactive.View.air3.Origin = {0, 0, 0};
    interactive.View.air3.Degrees = {0, 0, 0};
    interactive.View.air3.LengthX = interactive.Model.LIni/2;
    interactive.View.air3.LengthY = interactive.Model.HIni/2*sf;  //Altura teniendo en cuenta la freeboard region
    interactive.View.air3.LengthZ =  0.01;
    for j in 1:interactive.View.M loop
      for i in 1:interactive.View.N loop  //20
        interactive.View.air3.scalars[i+(j-1)*interactive.View.N] = interactive.Model.Tg[i+interactive.View.N,j+interactive.View.M];
      end for;
    end for;
    interactive.View.air3.posGrid = {0,interactive.Model.HIni*sf*5/8,0.0};
    
    interactive.View.airFB.Position = {0, 0, 0};
    interactive.View.airFB.Origin = {0, 0, 0};
    interactive.View.airFB.Degrees = {0, 0, 0};
    interactive.View.airFB.LengthX = interactive.Model.LIni;
    interactive.View.airFB.LengthY = interactive.Model.HIni/4*sf;  //Altura teniendo en cuenta la freeboard region
    interactive.View.airFB.LengthZ =  0.01;
      for i in 1:30 loop  //20
        interactive.View.airFB.scalars[i] = interactive.Model.Tfb[i];
      end for;
    interactive.View.airFB.posGrid = {-interactive.Model.LIni/2,interactive.Model.HIni*sf*9/8,0.0};
    
    interactive.View.arrowL.Position = {-interactive.Model.L/2-interactive.Model.L*0.025*3, 9/8*interactive.Model.H*sf+interactive.Model.H*sf*0.3, 0};
    interactive.View.arrowL.Origin = {0, 0, 0};
    interactive.View.arrowL.Degrees = {0, 180, 0};
    interactive.View.arrowL.scale = 1.0;
    
    interactive.View.arrowR.Position = {interactive.Model.L/2+interactive.Model.L*0.025*3, 9/8*interactive.Model.H*sf+interactive.Model.H*sf*0.3, 0};
    interactive.View.arrowR.Origin = {0, 0, 0};
    interactive.View.arrowR.Degrees = {0, 0, 0};
    interactive.View.arrowR.scale = 1.0;
    
    interactive.View.arrowR1.Position = {interactive.Model.L/2+interactive.Model.L*0.025*3, -7/8*interactive.Model.H*sf+interactive.Model.H*sf*0.3, 0};
    interactive.View.arrowR1.Origin = {0, 0, 0};
    interactive.View.arrowR1.Degrees = {0, 0, 0};
    interactive.View.arrowR1.scale = 1.0;
  //Interactive Controls
    
    interactive.View.tempClinker.var = interactive.Model.Ts_in;
    interactive.View.mflowClinker.var = interactive.Model.FMs_total;
    interactive.View.tempAir.var = interactive.Model.Tg_in;
    //interactive.View.vyAir.var = interactive.Model.ug_y[1];
    
    interactive.View.trail1ClinkerT.x = 1:30;
    interactive.View.trail1ClinkerT.y = interactive.Model.Ts[:,1];  //Ts[N,M];
    interactive.View.trail10ClinkerT.x = 1:30;
    interactive.View.trail10ClinkerT.y = interactive.Model.Ts[:,10];  //Ts[N,M];
    interactive.View.trail20ClinkerT.x = 1:30;
    interactive.View.trail20ClinkerT.y = interactive.Model.Ts[:,20];  //Ts[N,M];
    
    interactive.View.trail1AirT.x = 1:20;
    interactive.View.trail1AirT.y = interactive.Model.Tg[1,:];  //Ts[N,M];
    interactive.View.trail10AirT.x = 1:20;
    interactive.View.trail10AirT.y = interactive.Model.Tg[15,:];  //Ts[N,M];
    interactive.View.trail20AirT.x = 1:20;
    interactive.View.trail20AirT.y = interactive.Model.Tg[30,:];  //Ts[N,M];
    
    interactive.View.trail1AirHT.x = 1:30;
    interactive.View.trail1AirHT.y = interactive.Model.Tg[:,1];  //Ts[N,M];
    interactive.View.trail10AirHT.x = 1:30;
    interactive.View.trail10AirHT.y = interactive.Model.Tg[:,10];  //Ts[N,M];
    interactive.View.trail20AirHT.x = 1:30;
    interactive.View.trail20AirHT.y = interactive.Model.Tg[:,20];  //Ts[N,M];
    
    interactive.View.trail1Cooler.x = 1:30;
    interactive.View.trail1Cooler.y = interactive.Model.Tf[:,1];  //Ts[N,M];
   interactive.View.trail10Cooler.x = 1:30;
    interactive.View.trail10Cooler.y = interactive.Model.Tf[:,10];  //Ts[N,M];
   interactive.View.trail20Cooler.x = 1:30;
    interactive.View.trail20Cooler.y = interactive.Model.Tf[:,20];  //Ts[N,M];
    
    interactive.View.length.var = interactive.Model.L;
    interactive.View.height.var = interactive.Model.H;
    
    interactive.View.porosity.var = interactive.Model.eps;//( unit="1", start=0.825, fixed=true) "Porosidad del clinker";
    interactive.View.density.var = interactive.Model.rho_s;//( unit="kg/m3", start = 1500, fixed=true) "Densidad del clinker";
    
    interactive.View.airDensity.var = interactive.Model.rho_g; //( unit="kg/m3", start = 1.184, fixed=true) "Densidad del aire";
    
    interactive.View.fan1.var = interactive.Model.FMg_vent[1];
    interactive.View.fan2.var = interactive.Model.FMg_vent[2];
    interactive.View.fan3.var = interactive.Model.FMg_vent[3];
    interactive.View.fan4.var = interactive.Model.FMg_vent[4];
    interactive.View.fan5.var = interactive.Model.FMg_vent[5];
    
    annotation (experiment(
        StopTime=1e+060,
        Interval=0.5,
        Tolerance=0.01,
        Algorithm="Dassl"), experimentSetupOutput(
        states=false,
        derivatives=false,
        inputs=false,
        outputs=false,
        auxiliaries=false,
        equdistant=false,
        events=false));
  end virtualLab;
  
model coolerInteractive2 
  protected 
   constant Integer N =  30 
      "Numero de volmenes de control en dimensin horizontal";
   constant Integer M =  20 
      "Numero de volmenes de control en dimensin vertical";
   // ------------
   // Ventiladores
   // ------------
   // Volmenes de control en los que introduce aire cada ventilador
   // Ventilador 1: i: N_vents[1], ..., N_vents[2]-1 : 1,2,3,4,5,6
   // Ventilador 2: i: N_vents[2], ..., N_vents[3]-1 : 7,8,9,10,11,12
   // Ventilador 3: i: N_vents[3], ..., N_vents[4]-1 : 13,14,15,16,17,18
   // Ventilador 4: i: N_vents[4], ..., N_vents[Nventiladores]-1 : 19,20,21,22,23,24
   // Ventilador Nventiladores=5: i: N_vents[Nventiladores], ..., N : 25,26,27,28,29,30
   constant Integer Nventiladores = 5 "Nmero de ventiladores";
   constant Integer N_vents[Nventiladores] = {1,7,13,19,25};
    
    // --------------------------------------
    // Posicin divisin en free board region
    // --------------------------------------
    // El aire recogido en  i:1,...,(NdivFreeBoard-1) sale por la izquierda
    // El aire recogido en  i: NdivFreeBoard, ..., N  sale por la derecha
    constant Integer NdivFreeBoard = 13;
    
   constant Boolean modeloDinamico = true;
   //cooler cool(N=N,M=M,Nventiladores=Nventiladores,N_vents=N_vents,NdivFreeBoard=NdivFreeBoard,modeloDinamico=modeloDinamico);
    
// ---------------------------------------------------
// ------- Variables manipuladas (inicio) ------------
// --- Parmetros modelo fsico
  public 
   Real L(unit="m", start=11, fixed=true) "Longitud del lecho: dimensin x";
   Real H(unit="m", start=0.8, fixed=true) "Altura del lecho: dimensin en y";
   Real eps( unit="1", start=0.825, fixed=true) "Porosidad del clinker";
   Real rho_s( unit="kg/m3", start = 1500, fixed=true) "Densidad del clinker";
   Real rho_g( unit="kg/m3", start = 1.184, fixed=true) "Densidad del aire";
   // Capacidades calorficas
   Real Cps( unit="J/(kg.K)", start = 1000, fixed=true) 
      "Capacidad calorfica del clinker";
   Real Cpg( unit="J/(kg.K)", start = 1009, fixed=true) 
      "Capacidad calorfica del aire";
   Real ks( unit="J/(m.s.K)", start = 0.5, fixed=true) 
      "Conductividad trmica del clinker";
   Real DiameterClinker( unit="m", start = 0.007, fixed=true) 
      "Diametro de la partcula de clinker";
   Real esfericidadPartClinker( unit="1", start = 1, fixed=true) 
      "Esfericidad de las particulas de clinker";
   Real es(  unit="1", start = 0.78, fixed=true) "Emisividad del clinker";
    
// --- Condiciones de contorno para el slido
   Real Ts_in(  unit="K", start=1673, fixed=true) 
      "Temperatura a la que entra en el enfriador el slido";
   Real FMs_total( unit="kg/s/m", start=30, fixed=true) 
      "Flujo msico total de slido";
    
// --- Condiciones de contorno para el gas
   Real Tg_in(  unit="K", start=300, fixed=true) "Temperatura del gas";
   Real FMg_vent[Nventiladores]( unit="kg/s/m", start={3,3,3,3,3}, fixed=true) 
      "Flujo msico total de cada ventilador";
    
// ------- Variables manipuladas (fin) ------------
// ------------------------------------------------
    
// ---------------------------------------------------
// ------- Variables observadas  (inicio) ------------
    
   // Free board region (FBR)
   Real Tfb[N]( unit="K") "Temperatura del gas en free board region";
   Real Tfb_left( unit="K") 
      "Temperatura del aire que sale de FBR por la izquierda";
   Real Tfb_right( unit="K") 
      "Temperatura del aire que sale de FBR por la derecha";
   Real FMfb_left_1( unit="kg/s/m") 
      "Flujo de masa que sale de FBR por la izquierda";
   Real FMfb_right_N( unit="kg/s/m") 
      "Flujo de masa que sale de FBR por la derecha";
    
   // Gas en el lecho
   Real Tg[N,M]( unit="K") "Temperatura del gas en el lecho";
   Real ug_y_vent[Nventiladores]( unit="m/s") 
      "Velocidad del gas, en sentido de abajo a arriba, producida por cada ventilador";
    
   // Slido en el lecho
   Real Ts[N,M]( unit="K") "Temperatura del slido";
   Real us_x( unit="m/s") 
      "Velocidad del slido, en sentido de izquierda a derecha";
   // Temperatura media gas-slido
   Real Tf[N,M]( unit="K") "Temperatura de media gas-slido";
    
   // Eficiencia
   Real eficiencia( unit="%") "Eficiencia del enfriador";
    
// ------- Variables observadas  (fin) ------------
// ------------------------------------------------
    
equation 
   // Variables manipuladas
   //L = cool.L;
   der(L) = 0;
   //H = cool.H;
   der(H) = 0;
   //eps = cool.eps;
   der(eps) = 0;
   //rho_s = cool.rho_s;
   der(rho_s) = 0;
   //rho_g = cool.rho_g;
   der(rho_g) = 0;
   //Cps = cool.Cps;
   der(Cps) = 0;
   //Cpg = cool.Cpg;
   der(Cpg) = 0;
   //ks = cool.ks;
   der(ks) = 0;
   //DiameterClinker = cool.DiameterClinker;
   der(DiameterClinker) = 0;
   //esfericidadPartClinker = cool.esfericidadPartClinker;
   der(esfericidadPartClinker) = 0;
   //es = cool.es;
   der(es) = 0;
   //Ts_in = cool.Ts_in;
   der(Ts_in) = 0;
   //FMs_total = cool.FMs_total;
   der(FMs_total) = 0;
   //Tg_in = cool.Tg_in;
   der(Tg_in) = 0;
   //FMg_vent = cool.FMg_vent;
   der(FMg_vent) = zeros(Nventiladores);
    
   // Variables observadas
   Tfb = ones(N);//cool.Tfb;
   Tfb_left = 1;//cool.Tfb[1];
   Tfb_right = 1;//cool.Tfb[N];
   FMfb_left_1 = 1;//-cool.FMfb_left[1];
   FMfb_right_N = 1;//-cool.FMfb_right[N];
   Tg = ones(N,M);//cool.Tg;
   Ts = ones(N,M);//cool.Ts;
   us_x = 1;//cool.us_x;
   Tf = ones(N,M);//cool.Tf;
   ug_y_vent = ones(Nventiladores);//cool.ug_y_vent;
   eficiencia = 1;//cool.eficiencia;
    
  annotation (experiment(
        StopTime=10,
        Interval=1e-005,
        Tolerance=0.01,
        Algorithm="Dassl"),
                          experimentSetupOutput(derivatives=false));
end coolerInteractive2;
  
  model View2 
    extends Interactive.VLabModels.PartialView;
    Interactive.ViewElements.Containers.MainWindow mW(
      LayoutPolicy="VBox",
      title="Cooler",
      Width=800,
      Height=700) annotation (extent=[-44,265; -16,295]);
    annotation (Coordsys(
        extent=[-100,-100; 200,300],
        grid=[1,1],
        scale=0.1), Diagram);
    Interactive.ViewElements.Containers.Canvas cV 
      annotation (extent=[-2,142; 18,162]);
    Interactive.ViewElements.Drawables.PlanarGrid clinker(
      minRangeCellLUT=250,
      maxRangeCellLUT=1650,
      displayVectors=0,
      minRangeVectorLUT=250,
      maxRangeVectorLUT=1650,
      dims={31,21,2},
      linearVectorLUT=0,
      linearCellLUT=1,
      intPos=0) 
      annotation (extent=[28,132; 48,152]);
    Interactive.ViewElements.Drawables.PlanarGrid air(
      dims={31,26,2},
      minRangeCellLUT=250,
      maxRangeCellLUT=1650,
      displayVectors=0,
      minRangeVectorLUT=250,
      maxRangeVectorLUT=1650,
      linearVectorLUT=0,
      linearScaleCellLUT=1,
      intPos=0) 
      annotation (extent=[27,107; 47,127]);
  equation 
    connect(root.cLLeft, mW.pLLeft) annotation (points=[-70.2,61; -70,61; -70,56;
          -57,56; -57,284.2; -42.6,284.2], style(color=0, rgbcolor={0,0,0}));
    connect(cV.cRight, clinker.pLeft) annotation (points=[17,152; 23,152; 23,147;
          29,147], style(color=0, rgbcolor={0,0,0}));
    connect(clinker.cLeft, air.pLeft) annotation (points=[29,139; 25,139; 25,122;
          28,122], style(color=0, rgbcolor={0,0,0}));
    connect(mW.cLRight, cV.pLLeft) annotation (points=[-17.4,280; -9,280; -9,
          157; -1,157], style(color=0, rgbcolor={0,0,0}));
  end View2;
end Cooler;
