model cooler "Modelo fsico" 
   parameter Integer N "Numero de volmenes de control en dimensin horizontal";
   parameter Integer M "Numero de volmenes de control en dimensin vertical";
  
   // ------------
   // Ventiladores
   // ------------
   // Volmenes de control en los que introduce aire cada ventilador
   // Ventilador 1: i: N_vents[1], ..., N_vents[2]-1 : 1,2,3,4,5,6
   // Ventilador 2: i: N_vents[2], ..., N_vents[3]-1 : 7,8,9,10,11,12
   // Ventilador 3: i: N_vents[3], ..., N_vents[4]-1 : 13,14,15,16,17,18
   // Ventilador 4: i: N_vents[4], ..., N_vents[Nventiladores]-1 : 19,20,21,22,23,24
   // Ventilador Nventiladores=5: i: N_vents[Nventiladores], ..., N : 25,26,27,28,29,30
   parameter Integer Nventiladores; // = 5 "Nmero de ventiladores";
   parameter Integer N_vents[Nventiladores]; // = {1,7,13,19,25};
  
    // --------------------------------------
    // Posicin divisin en free board region
    // --------------------------------------
    // El aire recogido en  i:1,...,(NdivFreeBoard-1) sale por la izquierda
    // El aire recogido en  i: NdivFreeBoard, ..., N  sale por la derecha
    parameter Integer NdivFreeBoard; // = 13;
  
    // Temperaturas aproximadas (cond. inic iteracin)
    parameter Real Tg_IN( unit="K") = 800;
    parameter Real Ts_IN( unit="K") = 1000;
  
   constant Real numericEps = 5 "Constante de tiempo del modelo dinmico";
   constant Boolean modeloDinamico;
  
   // Dimensiones de la unidad de proceso
   Real L(unit="m") "Longitud: dimensin x";
   Real H(unit="m") "Altura: dimensin en y";
  
   // Parmetros relacionados con el tamao del volumen de control
   Real VC_x( unit="m");
   Real VC_y( unit="m");
   Real VC_xy( unit="m2");
  
   // Porosidad
   Real eps( unit="1");
   // Densidades
   Real rho_s( unit="kg/m3");
   Real rho_g( unit="kg/m3");
   // Capacidades calorficas
   Real Cps( unit="J/(kg.K)");
   Real Cpg( unit="J/(kg.K)");
  
   // Conductividad trmica del clinker
   Real ks( unit="J/(m.s.K)");
   Real ks_x( unit="J/(m.s.K)") 
    "Coef transmisin de calor por conduccin en el slido en direccin x";
   Real ks_y( unit="J/(m.s.K)") 
    "Coef transmisin de calor por conduccin en el slido en direccin y";
  
   // Parmetros del flujo de calor por conveccin
   Real DiameterClinker( unit="m") "Diametro del clinker";
   Real a(  unit="1/m");
   Real esfericidadPartClinker( unit="1") 
    "Esfericidad de las particulas de clinker";
   Real CteNumReynolds_g( unit="Kg/(m.s)") 
    "Parte constante del nmero de Reynolds";
  
   // Parmetros del flujo por radiacin
   constant Real sig(   unit="W/(m2.K4)") = 5.670373e-8 
    "Constante de Stefan-Boltzman";
   Real es(  unit="1") "Emisividad del clinker";
   Real Krad(   unit="W/(m.K4)");
  
   // -------------- inicio (free board region) ---------------------
   // Free board region
   Real Tfb[N]( unit="K", start=Tg_IN*ones(N), fixed=modeloDinamico) 
    "temperatura del gas en free board region";
  
   Real FMfb_left[N]( unit="kg/(s.m)") 
    "flujo msico de gas que entra por el lado izquierdo";
   Real FMfb_right[N]( unit="kg/(s.m)") 
    "flujo msico de gas que entra por el lado derecho";
   Real FMfb_bot[N]( unit="kg/(s.m)") 
    "flujo msico de gas que entra por debajo";
  
   Real Ffb_left[N]( unit="J/(m.s)") 
    "Flujo de entalpa que entra por el lado izquierdo";
   Real Ffb_right[N]( unit="J/(m.s)") 
    "Flujo de entalpa que entra por el lado izquierdo";
   Real Ffb_bot[N]( unit="J/(m.s)") 
    "Flujo de entalpa que entra por el lado izquierdo";
   Real Rad[N]( unit="J/(m.s)") "Flujo de energa que entra por radiacin";
   // -------------- fin (free board region) ---------------------
  
   // Temperatura de gas, de slido y de la capa lmite
   Real Tg[N,M]( unit="K", start=Tg_IN*ones(N,M), fixed=modeloDinamico) 
    "temperatura del gas";
   Real Ts[N,M]( unit="K", start=Ts_IN*ones(N,M), fixed=modeloDinamico) 
    "temperatura del slido";
   Real Tf[N,M]( unit="K") "temperatura de la capa lmite gas-slido";
  
   // Flujos de entalpa debido al slido entrante al volumen de control
   Real Fs_left[N,M](    unit="J/(m.s)") 
    "Flujo de entalpa debido al slido que entra por lado izquierdo";
   Real Fs_right[N,M](   unit="J/(m.s)") 
    "Flujo de entalpa debido al slido que entra por lado derecho";
  
   // Flujos de entalpa debido al gas entrante al volumen de control
   Real Fg_bot[N,M](  unit="J/(m.s)") 
    "Flujo de entalpa debido al slido que entra por lado inferior";
   Real Fg_up[N,M](  unit="J/(m.s)") 
    "Flujo de entalpa debido al slido que entra por lado superior";
  
   // Flujos de calor en el slido entrantes por conduccin
   Real Qs_left[N,M](  unit="J/(m.s)") 
    "Flujo de calor que entra por lado izquierdo por conduccin en el slido";
   Real Qs_right[N,M](  unit="J/(m.s)") 
    "Flujo de calor que entra por lado derecho por conduccin en el slido";
   Real Qs_bot[N,M](  unit="J/(m.s)") 
    "Flujo de calor que entra por lado inferior por conduccin en el slido";
   Real Qs_up[N,M](  unit="J/(m.s)") 
    "Flujo de calor que entra por lado superior por conduccin en el slido";
  
  //  Flujo de calor del slido al gas por conveccin
  Real Qsg[N,M](  unit="J/(m.s)") 
    "Flujo de calor transmitido del slido al gas por conveccin";
  Real NumReynolds_g[N,M]( unit="1") "Nmero de Reynolds del gas";
  
  constant Real viscosity_g_coef1 = 0.01827e-3*(0.555*524.07+120)*(9/5/524.07)^(3/2);
  constant Real viscosity_g_coef2 = 0.555*9/5;
  Real viscosity_g[N,M]( unit="kg/(m.s)") "Viscosidad del gas";
  // Real factorChiltonColburn[N,M]( unit="1") "factor de Chilton-Colburn";
  Real hcc[N,M](   unit="J/(m2.s.K)") 
    "Coeficiente transferencia de calor por conveccin";    // = 74;
  Real kg[N,M](  unit="J/(m.s.K)") "Conductividad trmica en el gas";
  Real Nusselt[N,M]( unit="1") "Nusselt number";
  Real Prandtl[N,M]( unit="1") "Prandtl number";
  
  // Flujo de calor del slido al gas por radiacin
  Real R[N,M](   unit="J/(m.s)") 
    "Flujo de calor por radiacin entre el slido y el gas";
  
  // Temperatura a la que entra el gas y el slido (condicin de contorno)
  Real Tg_in(  unit="K") "Temperatura a la que entra en el enfriador el gas";
  Real Ts_in(  unit="K") "Temperatura a la que entra en el enfriador el slido";
  
  // Velocidades de movimiento del gas y del slido
  Real ug_y[N]( unit="m/s") "Velocidad del gas, en sentido de abajo a arriba";
  Real ug_y_vent[Nventiladores]( unit="m/s") 
    "Velocidad del gas, en sentido de abajo a arriba, producida por cada ventilador";
  
  Real us_x( unit="m/s") 
    "Velocidad del slido, en sentido de izquierda a derecha";
  
  // Flujo msico de slido y gas
   Real K_ug( unit="kg/m2") 
    "Constante de proporcionalidad entre el flujo y la velocidad";
   Real FMs(  unit="kg/(s.m)") 
    "Flujo msico de slido a traves de cada volumen de control";
   Real FMg[N](  unit="kg/(s.m)") 
    "Flujo msico de gas a traves de cada volumen de control";
   Real FMs_total( unit="kg/(s.m)") "Flujo msico total de slido";
   Real FMg_total( unit="kg/(s.m)") "Flujo msico total de aire";
   Real FMg_vent[Nventiladores]( unit="kg/(s.m)") 
    "Flujo msico total de cada ventilador";
  
   // Eficiencia
   Real eficiencia( unit="%") "Eficiencia del enfriador";
  
   Real residuoEnergia;
equation 
  
   // Magnitudes relacionadas con el tamao del volumen de control
   VC_x = L/N;
   VC_y = H/M;
   VC_xy = VC_x*VC_y;
  
   // Coef transmisin de calor por conduccin en el slido en direccin x
   ks_x =  VC_y*ks*(1-eps)/VC_x;
   // Coef transmisin de calor por conduccin en el slido en direccin y
   ks_y =  VC_x*ks*(1-eps)/VC_y;
  
   // Flujo msico de slido y de gas
   FMs = VC_y*rho_s*(1-eps)*us_x;
   // FMg = VC_x*rho_g*eps*ug_y;
   FMs_total = rho_s*(1-eps)*us_x*H;
   FMg_total = FMg_vent*ones(Nventiladores);
  
   // Velocidades del gas
   K_ug = VC_x*rho_g*eps;
   for i in 1:(Nventiladores-1) loop
      for j in N_vents[i]:(N_vents[i+1]-1) loop
         FMg[j] = K_ug*ug_y[j];
         FMg[j] = FMg_vent[i]/(N_vents[i+1]-N_vents[i]);
      end for;
   end for;
   for j in N_vents[Nventiladores]:N loop
      FMg[j] = K_ug*ug_y[j];
      FMg[j] = FMg_vent[Nventiladores]/(N+1-N_vents[Nventiladores]);
   end for;
   for i in 1:Nventiladores loop
      ug_y_vent[i] = ug_y[N_vents[i]];
   end for;
  
   // Balance de energa en el slido
   if (modeloDinamico) then
      Fs_left + Fs_right + Qs_left + Qs_right + Qs_bot + Qs_up - Qsg - R = numericEps*der(Ts);
   else
      Fs_left + Fs_right + Qs_left + Qs_right + Qs_bot + Qs_up - Qsg - R = zeros(N,M);
   end if;
  
   // Balance de energa en el gas
   if (modeloDinamico) then
      Fg_bot + Fg_up + Qsg = numericEps*der(Tg);
   else
      Fg_bot + Fg_up + Qsg = zeros(N,M);
   end if;
  
  // Flujos de entalpa del slido
  for i in 1:N loop
     for j in 1:M loop
        Fs_right[i,j] = - FMs*Cps*Ts[i,j];
     end for;
  end for;
  for j in 1:M loop
     Fs_left[1,j] = FMs*Cps*Ts_in;
     for i in 2:N loop
        Fs_left[i,j] = - Fs_right[i-1,j];
     end for;
  end for;
  
  // Flujos de entalpa del gas
  for i in 1:N loop
     for j in 1:M loop
        Fg_up[i,j] = - FMg[i]*Cpg*Tg[i,j];
     end for;
  end for;
  for i in 1:N loop
     Fg_bot[i,1] = FMg[i]*Cpg*Tg_in;
     for j in 2:M loop
        Fg_bot[i,j] = - Fg_up[i,j-1];
     end for;
  end for;
  
  // Flujos de calor por conduccin en el slido
  for j in 1:M loop
     Qs_left[1,j] = 0;
     for i in 2:N loop
       Qs_left[i,j] = ks_x*(Ts[i-1,j]-Ts[i,j]);
     end for;
  end for;
  for j in 1:M loop
     for i in 1:(N-1) loop
       Qs_right[i,j] = ks_x*(Ts[i+1,j]-Ts[i,j]);
     end for;
     Qs_right[N,j] = 0;
  end for;
  
  for i in 1:N loop
     Qs_bot[i,1] = 0;
     for j in 2:M loop
        Qs_bot[i,j] = ks_y*(Ts[i,j-1]-Ts[i,j]);
     end for;
  end for;
  for i in 1:N loop
     for j in 1:(M-1) loop
        Qs_up[i,j] = ks_y*(Ts[i,j+1]-Ts[i,j]);
     end for;
     Qs_up[i,M] = 0;
  end for;
  
   // Flujos de calor del slido al gas por conveccin
   a = 6*(1-eps)/DiameterClinker;
   for i in 1:N loop
     for j in 1:M loop
        Qsg[i,j] = VC_xy*a*hcc[i,j]*( Ts[i,j] - Tg[i,j]);
     end for;
   end for;
   // Numero de Reynolds, viscosidad del gas, temperatura capa lmite gas-slido
   // Conductividad trmica del gas, Coef transferencia calor por conveccin
   CteNumReynolds_g = DiameterClinker*rho_g/(1-eps)/esfericidadPartClinker;
  
   for i in 1:N loop
      for j in 1:M loop
         Tf[i,j] = (Tg[i,j]+Ts[i,j])/2;
         viscosity_g[i,j]   = viscosity_g_coef1/(viscosity_g_coef2*Tf[i,j]+120)*Tf[i,j]^1.5;
         // viscosity_g[i,j]   = 0.01827e-3*(0.555*524.07+120)/(0.555*Tf[i,j]*9/5+120)*(Tf[i,j]*9/5/524.07)^(3/2);
         NumReynolds_g[i,j] = CteNumReynolds_g*ug_y[i]/viscosity_g[i,j];
         //factorChiltonColburn[i,j] = 2.19*NumReynolds_g[i,j]^(-2/3) + 0.78*NumReynolds_g[i,j]^(-0.381);
         // kg[i,j]=1.5207*1e-11*(Tf[i,j])^3-4.8574*1e-8*(Tf[i,j])^2+1.0184*1e-4*Tf[i,j]-3.9333*1e-4;
         kg[i,j]=7e-5*Tf[i,j]+0.0042;
         // hcc[i,j] = factorChiltonColburn[i,j]*rho_g*ug_y[i]*kg[i,j]/viscosity_g[i,j];
      
         hcc[i,j] = Nusselt[i,j]*kg[i,j]/DiameterClinker;
         // Ec. (3.32) del libro de Mujundar y Ramade
         // Nusselt[i,j]=8.74+9.34*(6*(1-eps))^0.2*NumReynolds_g[i,j]^0.2*Prandtl[i,j]^(1/3);
         // Ec. (21) del artculo de Touil et al., que proviene del handbook de Perry
         Nusselt[i,j]=0.0295*NumReynolds_g[i,j]^0.8*Prandtl[i,j]^0.333333;
         Prandtl[i,j]=viscosity_g[i,j]*Cpg/kg[i,j];
      end for;
   end for;
  
   // Flujo de calor por radiacin entre el slido y el gas
   for i in 1:N loop
      R[i,M] = Rad[i];
      for j in 1:(M-1) loop
         R[i,j] = 0;
      end for;
   end for;
  
   // ---------------------------------------------------
   // Free board area
   // ---------------------------------------------------
   // Balance de masa en el estacionario en free board area
   FMfb_left + FMfb_right + FMfb_bot = zeros(N);
   FMfb_left[NdivFreeBoard] = 0;
   for i in 2:N loop
      FMfb_left[i] = - FMfb_right[i-1];
   end for;
   FMfb_bot = FMg;
  
   // Balance de energa en free board region
   if (modeloDinamico) then
      Ffb_left + Ffb_right + Ffb_bot + Rad = numericEps*der(Tfb);
   else
      Ffb_left + Ffb_right + Ffb_bot + Rad = zeros(N);
   end if;
  
   // Flujo de entalpa
   Ffb_left[NdivFreeBoard] = 0;
   for i in 2:N loop
      Ffb_left[i] = - Ffb_right[i-1];
   end for;
   for i in 1:N loop
      Ffb_bot[i] = - Fg_up[i,M];
   end for;
   Krad =  VC_x*sig*es*(1-eps);
   for i in 1:N loop
      Rad[i] = Krad*(Ts[i,M]^4 - Tfb[i]^4);
   end for;
  
   // Relacin entre flujos de entalpa, flujo de masa y temperatura
   for i in 1:(NdivFreeBoard-1) loop
      Ffb_left[i] = FMfb_left[i]*Cpg* Tfb[i];
   end for;
   for i in NdivFreeBoard:N loop
      Ffb_right[i] = FMfb_right[i]*Cpg* Tfb[i];
   end for;
  
   // ---------------------------------------------------
  
   // Eficiencia
  
   eficiencia = -100*Ffb_left[1] / sum( Fs_left[1,j] for j in 1:M);
   residuoEnergia =
      sum( Fs_right[N,j] for j in 1:M) +
      sum( Fs_left[1,j] for j in 1:M) +
      sum( Fg_bot[i,1] for i in 1:N) +
      Ffb_left[1]+
      Ffb_right[N];
end cooler;


model coolerInteractive 
  
protected 
   constant Real Kelvin_to_C = 273.16;
   constant Real Kg_s_to_ton_day = 60*60*24/1000;
  
   constant Integer N =  30 
    "Numero de volmenes de control en dimensin horizontal";
   constant Integer M =  20 
    "Numero de volmenes de control en dimensin vertical";
   // ------------
   // Ventiladores
   // ------------
   // Volmenes de control en los que introduce aire cada ventilador
   // Ventilador 1: i: N_vents[1], ..., N_vents[2]-1 : 1,2,3,4,5,6
   // Ventilador 2: i: N_vents[2], ..., N_vents[3]-1 : 7,8,9,10,11,12
   // Ventilador 3: i: N_vents[3], ..., N_vents[4]-1 : 13,14,15,16,17,18
   // Ventilador 4: i: N_vents[4], ..., N_vents[Nventiladores]-1 : 19,20,21,22,23,24
   // Ventilador Nventiladores=5: i: N_vents[Nventiladores], ..., N : 25,26,27,28,29,30
   constant Integer Nventiladores = 5 "Nmero de ventiladores";
   constant Integer N_vents[Nventiladores] = {1,7,13,19,25};
  
    // --------------------------------------
    // Posicin divisin en free board region
    // --------------------------------------
    // El aire recogido en  i:1,...,(NdivFreeBoard-1) sale por la izquierda
    // El aire recogido en  i: NdivFreeBoard, ..., N  sale por la derecha
    constant Integer NdivFreeBoard = 13;
  
   constant Boolean modeloDinamico = true;
   cooler cool(N=N,M=M,Nventiladores=Nventiladores,N_vents=N_vents,NdivFreeBoard=NdivFreeBoard,modeloDinamico=modeloDinamico);
  
// ---------------------------------------------------
// ------- Variables manipuladas (inicio) ------------
// --- Parmetros modelo fsico
public 
   Real L(unit="m", start=11, fixed=true) "Longitud del lecho: dimensin x";
   Real H(unit="m", start=0.8, fixed=true) "Altura del lecho: dimensin en y";
   Real eps( unit="1", start=0.825, fixed=true) "Porosidad del clinker";
   Real rho_s( unit="kg/m3", start = 1500, fixed=true) "Densidad del clinker";
   Real rho_g( unit="kg/m3", start = 1.184, fixed=true) "Densidad del aire";
   // Capacidades calorficas
   Real Cps( unit="J/(kg.K)", start = 1000, fixed=true) 
    "Capacidad calorfica del clinker";
   Real Cpg( unit="J/(kg.K)", start = 1009, fixed=true) 
    "Capacidad calorfica del aire";
   Real ks( unit="J/(m.s.K)", start = 0.5, fixed=true) 
    "Conductividad trmica del clinker";
   Real DiameterClinker( unit="m", start = 0.007, fixed=true) 
    "Diametro de la partcula de clinker";
   Real esfericidadPartClinker( unit="1", start = 1, fixed=true) 
    "Esfericidad de las particulas de clinker";
   Real es(  unit="1", start = 0.78, fixed=true) "Emisividad del clinker";
  
// --- Condiciones de contorno para el slido
   Real Ts_in(  unit="C", start=1673-Kelvin_to_C, fixed=true) 
    "Temperatura a la que entra en el enfriador el slido";
   Real FMs_total( unit="ton/day/m", start=30*Kg_s_to_ton_day, fixed=true) 
    "Flujo msico total de slido";
  
// --- Condiciones de contorno para el gas
   Real Tg_in(  unit="C", start=300-Kelvin_to_C, fixed=true) 
    "Temperatura del gas";
   Real FMg_vent[Nventiladores]( unit="kg/s/m", start={3,3,3,3,3}, fixed=true) 
    "Flujo msico total de cada ventilador";
  
// ------- Variables manipuladas (fin) ------------
// ------------------------------------------------
  
// ---------------------------------------------------
// ------- Variables observadas  (inicio) ------------
  
   // Free board region (FBR)
   Real Tfb[N]( unit="C") "Temperatura del gas en free board region";
   Real Tfb_left( unit="C") 
    "Temperatura del aire que sale de FBR por la izquierda";
   Real Tfb_right( unit="C") 
    "Temperatura del aire que sale de FBR por la derecha";
   Real FMfb_left_1( unit="kg/s/m") 
    "Flujo de masa que sale de FBR por la izquierda";
   Real FMfb_right_N( unit="kg/s/m") 
    "Flujo de masa que sale de FBR por la derecha";
  
   // Gas en el lecho
   Real Tg[N,M]( unit="C") "Temperatura del gas en el lecho";
   Real ug_y_vent[Nventiladores]( unit="m/s") 
    "Velocidad del gas, en sentido de abajo a arriba, producida por cada ventilador";
  
   // Slido en el lecho
   Real Ts[N,M]( unit="C") "Temperatura del slido";
   Real us_x( unit="m/s") 
    "Velocidad del slido, en sentido de izquierda a derecha";
   // Temperatura media gas-slido
   Real Tf[N,M]( unit="C") "Temperatura media gas-slido";
  
   // Temperatura promedio de salida del clinker
   Real Ts_out_promedio(  unit="C") 
    "Temperatura promedio de salida del clinker";
  
   // Eficiencia
   Real eficiencia( unit="%") "Eficiencia del enfriador";
  
// ------- Variables observadas  (fin) ------------
// ------------------------------------------------
  
equation 
   // Variables manipuladas
   L = cool.L;
   der(L) = 0;
   H = cool.H;
   der(H) = 0;
   eps = cool.eps;
   der(eps) = 0;
   rho_s = cool.rho_s;
   der(rho_s) = 0;
   rho_g = cool.rho_g;
   der(rho_g) = 0;
   Cps = cool.Cps;
   der(Cps) = 0;
   Cpg = cool.Cpg;
   der(Cpg) = 0;
   ks = cool.ks;
   der(ks) = 0;
   DiameterClinker = cool.DiameterClinker;
   der(DiameterClinker) = 0;
   esfericidadPartClinker = cool.esfericidadPartClinker;
   der(esfericidadPartClinker) = 0;
   es = cool.es;
   der(es) = 0;
   Ts_in = cool.Ts_in - Kelvin_to_C;
   der(Ts_in) = 0;
   FMs_total = cool.FMs_total * Kg_s_to_ton_day;
   der(FMs_total) = 0;
   Tg_in = cool.Tg_in - Kelvin_to_C;
   der(Tg_in) = 0;
   FMg_vent = cool.FMg_vent;
   der(FMg_vent) = zeros(Nventiladores);
  
   // Variables observadas
   Tfb = cool.Tfb - Kelvin_to_C*ones(N);
   Tfb_left = cool.Tfb[1] - Kelvin_to_C;
   Tfb_right = cool.Tfb[N] - Kelvin_to_C;
   FMfb_left_1 = -cool.FMfb_left[1];
   FMfb_right_N = -cool.FMfb_right[N];
   Tg = cool.Tg - Kelvin_to_C*ones(N,M);
   Ts = cool.Ts - Kelvin_to_C*ones(N,M);
   us_x = cool.us_x;
   Tf = cool.Tf - Kelvin_to_C*ones(N,M);
   ug_y_vent = cool.ug_y_vent;
   eficiencia = cool.eficiencia;
  
   Ts_out_promedio = sum( Ts[N,i] for i in 1:M) /M;
  annotation (experiment(
      Interval=0.5,
      Tolerance=0.01,
      Algorithm="Dassl"), experimentSetupOutput(derivatives=false));
end coolerInteractive;

